@@ -1,8 +1,8 @@
 /*
  *  Hamlib Alinco backend - main file
- *  Copyright (c) 2001-2003 by Stephane Fillod
+ *  Copyright (c) 2001-2004 by Stephane Fillod
  *
- *	$Id: alinco.c,v 1.21 2004/02/15 00:30:29 fillods Exp $
+ *	$Id: alinco.c,v 1.24 2004/09/26 08:34:53 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -119,9 +119,16 @@ int alinco_transaction(RIG *rig, const char *cmd, int cmd_len, char *data, int *
 	/* if (retval <= 3)
 			return retval; */
 
-	/* no data expected, TODO: flush input? */
-	if (!data || !data_len)
-			return 0;
+	/* no data expected, check for OK returned */
+	if (!data || !data_len) {
+	    	retval = read_string(&rs->rigport, echobuf, BUFSZ, LF, strlen(LF));
+		retval -= 2;
+		echobuf[retval] = 0;
+		if (strcmp(echobuf, "OK") == 0) 
+			return RIG_OK;
+		else
+			return RIG_ERJCTED;
+	}
 
 	*data_len = read_string(&rs->rigport, data, BUFSZ, LF, strlen(LF));
 
@@ -488,6 +495,9 @@ int alinco_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 			cmd_len = sprintf(cmdbuf, AL CMD_NB "%d" EOM, status?1:0);
 
 			return alinco_transaction (rig, cmdbuf, cmd_len, NULL, NULL);
+	        case RIG_FUNC_COMP:
+			cmd_len = sprintf(cmdbuf, AL CMD_SDATA "C%d" EOM, status?1:0);
+			return alinco_transaction (rig, cmdbuf, cmd_len, NULL, NULL);
 
 		case RIG_FUNC_MON:
 			cmd_len = sprintf(cmdbuf, AL CMD_MON "%d" EOM, status?1:0);
@@ -594,6 +604,53 @@ int alinco_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 		case RIG_LEVEL_RFPOWER:
 			cmd_len = sprintf(cmdbuf, AL CMD_PWR "%1d" EOM, val.f<0.5 ? 1 : 0);
 
+			return alinco_transaction (rig, cmdbuf, cmd_len, NULL, NULL);
+		case RIG_LEVEL_KEYSPD:
+			if (val.i < 6) {
+			    lvl = 31;
+			} else if(val.i >= 6 && val.i < 20) {
+			    lvl = val.i + 25;
+			} else if(val.i >= 20 && val.i <= 50) {
+			    lvl = val.i - 20;
+			} else {
+			    lvl = 30;
+			}
+			cmd_len = sprintf(cmdbuf, AL CMD_SDATA "P%02d" EOM, lvl);
+
+			return alinco_transaction (rig, cmdbuf, cmd_len, NULL, NULL);
+
+		case RIG_LEVEL_CWPITCH:
+		    	if(val.i < 426) {
+			    lvl = 5;
+			} else if(val.i >= 426 && val.i <= 475) {
+			    lvl = 6;
+			} else if(val.i >= 476 && val.i <= 525) {
+			    lvl = 7;
+			} else if(val.i >= 526 && val.i <= 575) {
+			    lvl = 8;
+			} else if(val.i >= 576 && val.i <= 625) {
+			    lvl = 9;
+			} else if(val.i >= 626 && val.i <= 675) {
+			    lvl = 10;
+			} else if(val.i >= 676 && val.i <= 725) {
+			    lvl = 11;
+			} else if(val.i >= 726 && val.i <= 775) {
+			    lvl = 12;
+			} else if(val.i >= 776 && val.i <= 825) {
+			    lvl = 0;
+			} else if(val.i >= 826 && val.i <= 875) {
+			    lvl = 1;
+			} else if(val.i >= 876 && val.i <= 925) {
+			    lvl = 2;
+			} else if(val.i >= 926 && val.i <= 975) {
+			    lvl = 3;
+			} else if(val.i >= 976 && val.i <= 1025) {
+			    lvl = 4;
+			} else {
+			    lvl = 4;
+		        }
+			cmd_len = sprintf(cmdbuf, AL CMD_SDATA "M%02d" EOM, lvl);
+
 			return alinco_transaction (rig, cmdbuf, cmd_len, NULL, NULL);
 
 		default:
@@ -601,6 +658,7 @@ int alinco_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 			return -RIG_EINVAL;
 		}
 
+
 		return RIG_OK;
 }
 
@@ -635,9 +693,6 @@ int alinco_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 			val->i = atoi(lvlbuf+3);
 			break;
 
-		case RIG_LEVEL_SQLSTAT:
-			return -RIG_ENIMPL;	/* get_dcd ? */
-
 		case RIG_LEVEL_PREAMP:
 			retval = current_data_read(rig, lvlbuf);
 			if (retval != RIG_OK)
@@ -690,6 +745,35 @@ int alinco_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 		return RIG_OK;
 }
 
+/*
+ * alinco_set_parm
+ */
+int alinco_set_parm(RIG *rig, setting_t parm, value_t val) {
+	int cmd_len;
+	char cmdbuf[BUFSZ];
+
+	/* Optimize:
+	 *   sort the switch cases with the most frequent first
+	 */
+	switch (parm) {
+	case RIG_PARM_BEEP:
+	    rig_debug(RIG_DEBUG_ERR,"val is %d\n", val.i);
+	    cmd_len = sprintf(cmdbuf, AL CMD_SDATA "A%d" EOM, val.i?1:0);
+	    return alinco_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+	case RIG_PARM_BACKLIGHT:
+	    rig_debug(RIG_DEBUG_ERR,"val is %0f\n", val.f);
+	    cmd_len = sprintf(cmdbuf, AL CMD_SDATA "O%d" EOM, (int)(val.f * 5));
+	    return alinco_transaction(rig, cmdbuf, cmd_len, NULL, NULL);
+
+	default:
+	    rig_debug(RIG_DEBUG_ERR,"Unsupported set_parm %d\n", parm);
+	    return -RIG_EINVAL;
+	}
+
+	return RIG_OK;
+}
+
+
 /*
  * alinco_set_ctcss_tone
  * Assumes rig!=NULL, rig->caps->ctcss_list != NULL
