@@ -2,7 +2,7 @@
  *  Hamlib CI-V backend - low level communication routines
  *  Copyright (c) 2000-2003 by Stephane Fillod
  *
- *	$Id: frame.c,v 1.21 2003/04/26 09:54:49 fillods Exp $
+ *	$Id: frame.c,v 1.25 2004/09/06 18:10:49 fineware Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -77,17 +77,18 @@ int make_cmd_frame(char frame[], char re_id, char cmd, int subcmd, const char *d
 }
 
 /*
- * icom_transaction
+ * icom_one_transaction
  * 
  * We assume that rig!=NULL, rig->state!= NULL, payload!=NULL, data!=NULL, data_len!=NULL
  * Otherwise, you'll get a nice seg fault. You've been warned!
  * payload can be NULL if payload_len == 0
  * subcmd can be equal to -1 (no subcmd wanted)
+ * if no answer is to be expected, data_len must be set to NULL to tell so
  *
  * return RIG_OK if transaction completed, 
  * or a negative value otherwise indicating the error.
  */
-int icom_transaction (RIG *rig, int cmd, int subcmd, const char *payload, int payload_len, char *data, int *data_len)
+int icom_one_transaction (RIG *rig, int cmd, int subcmd, const char *payload, int payload_len, char *data, int *data_len)
 {
 		struct icom_priv_data *priv;
 		struct rig_state *rs;
@@ -117,7 +118,7 @@ int icom_transaction (RIG *rig, int cmd, int subcmd, const char *payload, int pa
 		/*
 		 * read what we just sent, because TX and RX are looped,
 		 * and discard it...
-		 * TODO: - if what we read is not what we sent, then it means
+		 * - if what we read is not what we sent, then it means
 		 * 			a collision on the CI-V bus occured!
 		 * 		- if we get a timeout, then retry to send the frame,
 		 * 			up to rs->retry times.
@@ -170,6 +171,14 @@ int icom_transaction (RIG *rig, int cmd, int subcmd, const char *payload, int pa
 		    return -RIG_EPROTO;
 		  }
 
+		/*
+		 * expect an answer?
+		 */
+		if (data_len == NULL) {
+		    Unhold_Decode(rig);
+		    return RIG_OK;
+		}
+
 		/*
 		 * wait for ACK ... 
 		 * FIXME: handle pading/collisions
@@ -213,6 +222,34 @@ int icom_transaction (RIG *rig, int cmd, int subcmd, const char *payload, int pa
 		return RIG_OK;
 }
 
+/*
+ * icom_transaction
+ * 
+ * This function honors rigport.retry count.
+ *
+ * We assume that rig!=NULL, rig->state!= NULL, payload!=NULL, data!=NULL, data_len!=NULL
+ * Otherwise, you'll get a nice seg fault. You've been warned!
+ * payload can be NULL if payload_len == 0
+ * subcmd can be equal to -1 (no subcmd wanted)
+ *
+ * return RIG_OK if transaction completed, 
+ * or a negative value otherwise indicating the error.
+ */
+int icom_transaction (RIG *rig, int cmd, int subcmd, const char *payload, int payload_len, char *data, int *data_len)
+{
+	int retval, retry;
+
+	retry = rig->state.rigport.retry;
+
+	do {
+		retval = icom_one_transaction (rig, cmd, subcmd, payload, payload_len, data, data_len);
+		if (retval == RIG_OK)
+			break;
+	} while (retry-- > 0);
+
+	return retval;
+}
+
 /* used in read_icom_frame as end of block */
 static const char icom_block_end[2] = {FI, COL};
 #define icom_block_end_length 2
@@ -256,10 +293,13 @@ int rig2icom_mode(RIG *rig, rmode_t mode, pbwidth_t width,
 
 		switch (mode) {
 		case RIG_MODE_AM:	icmode = S_AM; break;
+		case RIG_MODE_AMS:	icmode = S_AMS; break;
 		case RIG_MODE_CW:	icmode = S_CW; break;
+		case RIG_MODE_CWR:	icmode = S_CWR; break;
 		case RIG_MODE_USB:	icmode = S_USB; break;
 		case RIG_MODE_LSB:	icmode = S_LSB; break;
 		case RIG_MODE_RTTY:	icmode = S_RTTY; break;
+		case RIG_MODE_RTTYR:	icmode = S_RTTYR; break;
 		case RIG_MODE_FM:	icmode = S_FM; break;
 		case RIG_MODE_WFM:	icmode = S_WFM; break;
 		default:
@@ -298,7 +338,9 @@ void icom2rig_mode(RIG *rig, unsigned char md, int pd, rmode_t *mode, pbwidth_t
 
 		switch (md) {
 		case S_AM:	*mode = RIG_MODE_AM; break;
+		case S_AMS:	*mode = RIG_MODE_AMS; break;
 		case S_CW:	*mode = RIG_MODE_CW; break;
+		case S_CWR:	*mode = RIG_MODE_CWR; break;
 		case S_FM:	if (rig->caps->rig_model == RIG_MODEL_ICR7000
 									&& pd == 0x00) {
 							*mode = RIG_MODE_USB;
@@ -311,6 +353,7 @@ void icom2rig_mode(RIG *rig, unsigned char md, int pd, rmode_t *mode, pbwidth_t
 		case S_USB:	*mode = RIG_MODE_USB; break;
 		case S_LSB:	*mode = RIG_MODE_LSB; break;
 		case S_RTTY:	*mode = RIG_MODE_RTTY; break;
+		case S_RTTYR:	*mode = RIG_MODE_RTTYR; break;
 		case 0xff:	*mode = RIG_MODE_NONE; break;	/* blank mem channel */
 
 		default:
@@ -318,6 +361,11 @@ void icom2rig_mode(RIG *rig, unsigned char md, int pd, rmode_t *mode, pbwidth_t
 							md);
 			*mode = RIG_MODE_NONE;
 		}
+		
+		/* IC-R75 returns passband indexes 1-wide, 2-normal,3-narrow */
+		if ((rig->caps->rig_model == RIG_MODEL_ICR75) || (rig->caps->rig_model == RIG_MODEL_IC756PROII))
+			pd = 3-pd;
+		
 		switch (pd) {
 			case 0x00: *width = rig_passband_narrow(rig, *mode); break;
 			case 0x01: *width = rig_passband_normal(rig, *mode); break;
