@@ -1,8 +1,8 @@
 /*
  *  Hamlib CI-V backend - description of IC-706 and variations
- *  Copyright (c) 2000-2003 by Stephane Fillod
+ *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: ic706.c,v 1.31 2003/04/06 18:40:35 fillods Exp $
+ *	$Id: ic706.c,v 1.36 2004/09/26 08:35:03 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -24,8 +24,11 @@
 #include "config.h"
 #endif
 
-#include <hamlib/rig.h>
+#include <stdlib.h>
+
+#include "hamlib/rig.h"
 #include "icom.h"
+#include "idx_builtin.h"
 
 #define IC706_ALL_RX_MODES (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_SSB|RIG_MODE_RTTY|RIG_MODE_FM|RIG_MODE_WFM)
 #define IC706_1MHZ_TS_MODES (RIG_MODE_AM|RIG_MODE_FM|RIG_MODE_WFM)
@@ -39,7 +42,7 @@
 
 #define IC706IIG_FUNC_ALL (RIG_FUNC_FAGC|RIG_FUNC_NB|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_TONE|RIG_FUNC_TSQL|RIG_FUNC_SBKIN|RIG_FUNC_FBKIN)
 
-#define IC706IIG_LEVEL_ALL (RIG_LEVEL_PREAMP|RIG_LEVEL_ATT|RIG_LEVEL_AGC|RIG_LEVEL_SQLSTAT|RIG_LEVEL_STRENGTH)
+#define IC706IIG_LEVEL_ALL (RIG_LEVEL_PREAMP|RIG_LEVEL_ATT|RIG_LEVEL_AGC|RIG_LEVEL_RAWSTR)
 
 #define IC706_VFO_ALL (RIG_VFO_A|RIG_VFO_B)
 
@@ -102,15 +105,14 @@
 static const struct icom_priv_caps ic706_priv_caps = { 
 		0x48,	/* default address */
 		0,		/* 731 mode */
-		ic706_ts_sc_list,
-		IC706IIG_STR_CAL
+		ic706_ts_sc_list
 };
 
 const struct rig_caps ic706_caps = {
 .rig_model =  RIG_MODEL_IC706,
 .model_name = "IC-706", 
 .mfg_name =  "Icom", 
-.version =  "0.2", 
+.version =  BACKEND_VER, 
 .copyright =  "LGPL",
 .status =  RIG_STATUS_UNTESTED,
 .rig_type =  RIG_TYPE_MOBILE,
@@ -201,6 +203,7 @@ const struct rig_caps ic706_caps = {
 		{RIG_MODE_WFM, kHz(230)},	/* WideFM, filter FL?? */
 		RIG_FLT_END,
 	},
+.str_cal = IC706IIG_STR_CAL,
 .priv =  (void*)&ic706_priv_caps,
 .rig_init =   icom_init,
 .rig_cleanup =   icom_cleanup,
@@ -233,15 +236,14 @@ const struct rig_caps ic706_caps = {
 static const struct icom_priv_caps ic706mkii_priv_caps = { 
 		0x4e,	/* default address */
 		0,		/* 731 mode */
-		ic706_ts_sc_list,
-		IC706IIG_STR_CAL
+		ic706_ts_sc_list
 };
 
 const struct rig_caps ic706mkii_caps = {
 .rig_model =  RIG_MODEL_IC706MKII,
 .model_name = "IC-706MkII", 
 .mfg_name =  "Icom", 
-.version =  "0.2", 
+.version =  BACKEND_VER, 
 .copyright =  "LGPL",
 .status =  RIG_STATUS_UNTESTED,
 .rig_type =  RIG_TYPE_MOBILE,
@@ -334,6 +336,7 @@ const struct rig_caps ic706mkii_caps = {
 		{RIG_MODE_WFM, kHz(230)},	/* WideFM, filter FL?? */
 		RIG_FLT_END,
 	},
+.str_cal = IC706IIG_STR_CAL,
 
 .priv =  (void*)&ic706mkii_priv_caps,
 .rig_init =   icom_init,
@@ -362,6 +365,24 @@ const struct rig_caps ic706mkii_caps = {
 
 };
 
+
+/*
+ * IC706MkIIG channel caps.
+ */
+#define IC706MKIIG_MEM_CAP {	\
+	.freq = 1,	\
+	.mode = 1,	\
+	.width = 1,	\
+	.split = 1,	\
+	.tx_freq = 1,	\
+	.tx_mode = 1,	\
+	.tx_width = 1,	\
+	.rptr_offs = 1,	\
+	.rptr_shift = 1, /* only set */	\
+	.funcs = IC706IIG_FUNC_ALL, \
+	.levels = RIG_LEVEL_SET(IC706IIG_LEVEL_ALL), \
+} 
+
 /*
  * Basically, the IC706MKIIG is an IC706MKII plus UHF, a DSP
  * and 50W VHF
@@ -369,20 +390,19 @@ const struct rig_caps ic706mkii_caps = {
 static const struct icom_priv_caps ic706mkiig_priv_caps = { 
 		0x58,	/* default address */
 		0,		/* 731 mode */
-		ic706_ts_sc_list,
-		IC706IIG_STR_CAL
+		ic706_ts_sc_list
 };
 
 const struct rig_caps ic706mkiig_caps = {
 .rig_model =  RIG_MODEL_IC706MKIIG,
 .model_name = "IC-706MkIIG", 
 .mfg_name =  "Icom", 
-.version =  "0.2", 
+.version =  BACKEND_VER, 
 .copyright =  "LGPL",
 .status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_MOBILE,
 .ptt_type =  RIG_PTT_NONE,
-.dcd_type =  RIG_DCD_NONE,
+.dcd_type =  RIG_DCD_RIG,
 .port_type =  RIG_PORT_SERIAL,
 .serial_rate_min =  300,
 .serial_rate_max =  19200,
@@ -400,7 +420,9 @@ const struct rig_caps ic706mkiig_caps = {
 .has_set_level =  RIG_LEVEL_SET(IC706IIG_LEVEL_ALL),
 .has_get_parm =  RIG_PARM_NONE,
 .has_set_parm =  RIG_PARM_NONE,	/* FIXME: parms */
-.level_gran =  {}, 		/* granularity */
+.level_gran = {
+	[LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
+	},
 .parm_gran =  {},
 .ctcss_list =  common_ctcss_list,
 .dcs_list =  NULL,
@@ -417,9 +439,9 @@ const struct rig_caps ic706mkiig_caps = {
 .chan_desc_sz =  0,
 
 .chan_list =  {
-				   {   1,  99, RIG_MTYPE_MEM, IC_MEM_CAP },
-				   { 100, 105, RIG_MTYPE_EDGE },    /* two by two */
-				   { 106, 107, RIG_MTYPE_CALL },
+				   {   1,  99, RIG_MTYPE_MEM, IC706MKIIG_MEM_CAP },
+				   { 100, 105, RIG_MTYPE_EDGE, IC706MKIIG_MEM_CAP },    /* two by two */
+				   { 106, 107, RIG_MTYPE_CALL, IC706MKIIG_MEM_CAP },
 				   RIG_CHAN_END,
 		},
 
@@ -480,6 +502,7 @@ const struct rig_caps ic706mkiig_caps = {
 		{RIG_MODE_WFM, kHz(230)},	/* WideFM, filter FL?? */
 		RIG_FLT_END,
 	},
+.str_cal = IC706IIG_STR_CAL,
 
 .cfgparams =  icom_cfg_params,
 .set_conf =  icom_set_conf,
@@ -517,6 +540,7 @@ const struct rig_caps ic706mkiig_caps = {
 .set_split_mode =  icom_set_split_mode,
 .get_split_mode =  icom_get_split_mode,
 .set_split_vfo =  icom_set_split_vfo,
+.get_split_vfo =  icom_mem_get_split_vfo,
 
 };
 
