@@ -1,8 +1,8 @@
 /*
  *  Hamlib Interface - API header
- *  Copyright (c) 2000-2003 by Stephane Fillod and Frank Singleton
+ *  Copyright (c) 2000-2004 by Stephane Fillod and Frank Singleton
  *
- *	$Id: rig.h,v 1.92 2004/02/09 22:07:21 fillods Exp $
+ *	$Id: rig.h,v 1.100 2004/09/25 14:31:38 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -24,11 +24,6 @@
 #define _RIG_H 1
 
 #include <hamlib/riglist.h>	/* list in another file to not mess up w/ this one */
-#include <sys/time.h>		/* required for struct timeval */
-
-#if defined(__CYGWIN__) || defined(_WIN32)
-#include <windows.h>		/* HANDLE definition */
-#endif
 
 /*! \file rig.h
  *  \ingroup rig
@@ -515,6 +510,7 @@ typedef int ant_t;
 #define RIG_ANT_1	RIG_ANT_N(0)
 #define RIG_ANT_2	RIG_ANT_N(1)
 #define RIG_ANT_3	RIG_ANT_N(2)
+#define RIG_ANT_4	RIG_ANT_N(3)
 
 
 /* TODO: kill me, and replace by real AGC delay */
@@ -523,7 +519,8 @@ enum agc_level_e {
 	RIG_AGC_SUPERFAST,
 	RIG_AGC_FAST,
 	RIG_AGC_SLOW,
-	RIG_AGC_USER		/*!< user selectable */
+	RIG_AGC_USER,		/*!< user selectable */
+	RIG_AGC_MEDIUM
 };
 
 /**
@@ -556,7 +553,7 @@ enum rig_level_e {
 	RIG_LEVEL_ATT =		(1<<1),	/*!< Attenuator, arg int (dB) */
 	RIG_LEVEL_VOX =		(1<<2),	/*!< VOX delay, arg int (tenth of seconds) */
 	RIG_LEVEL_AF =		(1<<3),	/*!< Volume, arg float [0.0..1.0] */
-	RIG_LEVEL_RF =		(1<<4),	/*!< RF gain (not TX power), arg float [0.0..1.0] or in dB ?? -20..20 ? */
+	RIG_LEVEL_RF =		(1<<4),	/*!< RF gain (not TX power), arg float [0.0..1.0] */
 	RIG_LEVEL_SQL =		(1<<5),	/*!< Squelch, arg float [0.0 .. 1.0] */
 	RIG_LEVEL_IF =		(1<<6),	/*!< IF, arg int (Hz) */
 	RIG_LEVEL_APF =		(1<<7),	/*!< APF, arg float [0.0 .. 1.0] */
@@ -585,6 +582,7 @@ enum rig_level_e {
 	RIG_LEVEL_SWR =		(1<<28),/*!< SWR, arg float */
 	RIG_LEVEL_ALC =		(1<<29),/*!< ALC, arg float */
 	RIG_LEVEL_STRENGTH =	(1<<30) /*!< Effective (calibrated) signal strength relative to S9, arg int (dB) */
+	/*RIG_LEVEL_BWC =		(1<<31)*/ /*!< Bandwidth Control, arg int (Hz) */
 };
 
 #define RIG_LEVEL_FLOAT_LIST (RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_SQL|RIG_LEVEL_APF|RIG_LEVEL_NR|RIG_LEVEL_PBT_IN|RIG_LEVEL_PBT_OUT|RIG_LEVEL_RFPOWER|RIG_LEVEL_MICGAIN|RIG_LEVEL_COMP|RIG_LEVEL_BALANCE|RIG_LEVEL_SWR|RIG_LEVEL_ALC|RIG_LEVEL_VOXGAIN|RIG_LEVEL_ANTIVOX)
@@ -698,12 +696,19 @@ typedef enum {
 	RIG_MODE_AMS =    	(1<<9),	/*!< Amplitude Modulation Synchronous */
 	RIG_MODE_PKTLSB =       (1<<10),/*!< Packet/Digital LSB mode (dedicated port) */
 	RIG_MODE_PKTUSB =       (1<<11),/*!< Packet/Digital USB mode (dedicated port) */
-	RIG_MODE_PKTFM =        (1<<12) /*!< Packet/Digital FM mode (dedicated port) */
+	RIG_MODE_PKTFM =        (1<<12),/*!< Packet/Digital FM mode (dedicated port) */
+	RIG_MODE_ECSSUSB =      (1<<13),/*!< Exalted Carrier Single Sideband USB */
+	RIG_MODE_ECSSLSB =      (1<<14),/*!< Exalted Carrier Single Sideband LSB */
+	RIG_MODE_FAX =          (1<<15) /*!< Facsimile Mode */
+
 } rmode_t;
 
 /** \brief macro for backends, no to be used by rig_set_mode et al. */
 #define RIG_MODE_SSB  	(RIG_MODE_USB|RIG_MODE_LSB)
 
+/** \brief macro for backends, no to be used by rig_set_mode et al. */
+#define RIG_MODE_ECSS   (RIG_MODE_ECSSUSB|RIG_MODE_ECSSLSB)
+
 
 #define RIG_DBLST_END 0		/* end marker in a preamp/att level list */
 #define RIG_IS_DBLST_END(d) ((d)==0)
@@ -1215,12 +1220,12 @@ typedef struct {
   } type;
   int fd;			/*!< File descriptor */
 #if defined(__CYGWIN__) || defined(_WIN32)
-  HANDLE handle;		/*!< Win32 handle for serial special handling (PTT,DCD,..) */
+  void* deprecated_handle;	/*!< Place holder for deprecated field */
 #endif
 
   int write_delay;		/*!< Delay between each byte sent out, in ms */
   int post_write_delay;		/*!< Delay between each commands send out, in ms */
-  struct timeval post_write_date;	/*!< hamlib internal use */
+  struct { int tv_sec,tv_usec; } post_write_date;	/*!< hamlib internal use */
   int timeout;			/*!< Timeout, in ms */
   int retry;			/*!< Maximum number of retries, 0 to disable */
 
@@ -1238,9 +1243,6 @@ typedef struct {
 	struct {
 		int pin;	/*!< Parrallel port pin number */
 	} parallel;		/*!< parallel attributes */
-	struct {
-		/* place holder */
-	} network;		/*!< Network attributes */
   } parm;			/*!< Port parameter union */
 } port_t;
 
@@ -1544,6 +1546,27 @@ extern HAMLIB_EXPORT(int) rig_probe_all HAMLIB_PARAMS((port_t *p, rig_probe_func
 extern HAMLIB_EXPORT(rig_model_t) rig_probe HAMLIB_PARAMS((port_t *p));
 
 
+/* Misc calls */
+extern HAMLIB_EXPORT(const char *) rig_strrmode(rmode_t mode);
+extern HAMLIB_EXPORT(const char *) rig_strvfo(vfo_t vfo);
+extern HAMLIB_EXPORT(const char *) rig_strfunc(setting_t);
+extern HAMLIB_EXPORT(const char *) rig_strlevel(setting_t);
+extern HAMLIB_EXPORT(const char *) rig_strparm(setting_t);
+extern HAMLIB_EXPORT(const char *) rig_strptrshift(rptr_shift_t);
+extern HAMLIB_EXPORT(const char *) rig_strvfop(vfo_op_t op);
+extern HAMLIB_EXPORT(const char *) rig_strscan(scan_t scan);
+extern HAMLIB_EXPORT(const char *) rig_strstatus(enum rig_status_e status);
+
+extern HAMLIB_EXPORT(rmode_t) rig_parse_mode(const char *s);
+extern HAMLIB_EXPORT(vfo_t) rig_parse_vfo(const char *s);
+extern HAMLIB_EXPORT(setting_t) rig_parse_func(const char *s);
+extern HAMLIB_EXPORT(setting_t) rig_parse_level(const char *s);
+extern HAMLIB_EXPORT(setting_t) rig_parse_parm(const char *s);
+extern HAMLIB_EXPORT(vfo_op_t) rig_parse_vfo_op(const char *s);
+extern HAMLIB_EXPORT(scan_t) rig_parse_scan(const char *s);
+extern HAMLIB_EXPORT(rptr_shift_t) rig_parse_rptr_shift(const char *s);
+
+
 __END_DECLS
 
 #endif /* _RIG_H */
