@@ -2,7 +2,7 @@
  *  Hamlib Interface - list of known rigs
  *  Copyright (c) 2000-2004 by Stephane Fillod and Frank Singleton
  *
- *	$Id: riglist.h,v 1.43 2004/02/08 17:03:25 fillods Exp $
+ *	$Id: riglist.h,v 1.49 2004/11/15 16:54:43 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -115,13 +115,13 @@
 #define RIG_MODEL_TS680S RIG_MAKE_MODEL(RIG_KENWOOD, 24)
 #define RIG_MODEL_TS140S RIG_MAKE_MODEL(RIG_KENWOOD, 25)
 #define RIG_MODEL_TMD700 RIG_MAKE_MODEL(RIG_KENWOOD, 26)
+#define RIG_MODEL_TMV7 RIG_MAKE_MODEL(RIG_KENWOOD, 27)
 
 	/*
 	 * Icom
 	 */
 #define RIG_ICOM 3
 #define RIG_BACKEND_ICOM "icom"
-#define RIG_MODEL_ICALL RIG_MAKE_MODEL(RIG_ICOM, 0)	/* deprecated */
 #define RIG_MODEL_IC1271 RIG_MAKE_MODEL(RIG_ICOM, 1)
 #define RIG_MODEL_IC1275 RIG_MAKE_MODEL(RIG_ICOM, 2)
 #define RIG_MODEL_IC271 RIG_MAKE_MODEL(RIG_ICOM, 3)
@@ -171,6 +171,9 @@
 #define RIG_MODEL_IC756PROII RIG_MAKE_MODEL(RIG_ICOM, 47)
 #define RIG_MODEL_ICID1 RIG_MAKE_MODEL(RIG_ICOM, 54)
 #define RIG_MODEL_IC703 RIG_MAKE_MODEL(RIG_ICOM, 55)
+#define RIG_MODEL_IC7800 RIG_MAKE_MODEL(RIG_ICOM, 56)
+#define RIG_MODEL_IC756PROIII RIG_MAKE_MODEL(RIG_ICOM, 57)
+#define RIG_MODEL_ICR20 RIG_MAKE_MODEL(RIG_ICOM, 58)
 
 	/*
 	 * Optoelectronics (CI-V)
@@ -210,6 +213,7 @@
 #define RIG_MODEL_AR2500 RIG_MAKE_MODEL(RIG_AOR, 9)
 #define RIG_MODEL_AR16 RIG_MAKE_MODEL(RIG_AOR, 10)
 #define RIG_MODEL_SDU5500 RIG_MAKE_MODEL(RIG_AOR, 11)
+#define RIG_MODEL_SDU5000 RIG_MAKE_MODEL(RIG_AOR, 12)
 
 	/*
 	 * JRC
@@ -283,6 +287,7 @@
 #define RIG_MODEL_HF1000 RIG_MAKE_MODEL(RIG_WJ, 1)
 #define RIG_MODEL_HF1000A RIG_MAKE_MODEL(RIG_WJ, 2)
 #define RIG_MODEL_WJ8711 RIG_MAKE_MODEL(RIG_WJ, 3)
+#define RIG_MODEL_WJ8888 RIG_MAKE_MODEL(RIG_WJ, 4)
 
 	/*
 	 * Rohde & Schwarz
@@ -305,7 +310,7 @@
 #define RIG_MODEL_TRP9000 RIG_MAKE_MODEL(RIG_SKANTI, 3)
 
 	/*
-	 * WiNRADiO/LinRADiO, by Rosetta Labs
+	 * WiNRADiO/LinRADiO
 	 */
 #define RIG_WINRADIO 15
 #define RIG_BACKEND_WINRADIO "winradio"
@@ -316,6 +321,7 @@
 #define RIG_MODEL_WR3150 RIG_MAKE_MODEL(RIG_WINRADIO, 5)
 #define RIG_MODEL_WR3500 RIG_MAKE_MODEL(RIG_WINRADIO, 6)
 #define RIG_MODEL_WR3700 RIG_MAKE_MODEL(RIG_WINRADIO, 7)
+#define RIG_MODEL_G303 RIG_MAKE_MODEL(RIG_WINRADIO, 8)
 
 	/*
 	 * Ten Tec
@@ -398,6 +404,22 @@
 #define RIG_BACKEND_RFT "rft"
 #define RIG_MODEL_EKD500 RIG_MAKE_MODEL(RIG_RFT, 1)
 
+	/*
+	 * Various kits
+	 */
+#define RIG_KIT 25
+#define RIG_BACKEND_KIT "kit"
+#define RIG_MODEL_ELEKTOR304 RIG_MAKE_MODEL(RIG_KIT, 1)
+#define RIG_MODEL_DRT1 RIG_MAKE_MODEL(RIG_KIT, 2)
+
+	/*
+	 * SW/FM/TV tuner cards supported by Video4Linux,*BSD, ..
+	 */
+#define RIG_TUNER 26
+#define RIG_BACKEND_TUNER "tuner"
+#define RIG_MODEL_V4L RIG_MAKE_MODEL(RIG_TUNER, 1)
+
+
 
 	/*
 	 * TODO:
@@ -445,6 +467,8 @@ typedef int rig_model_t;
 		{ RIG_TAPR, RIG_BACKEND_TAPR }, \
 		{ RIG_FLEXRADIO, RIG_BACKEND_FLEXRADIO }, \
 		{ RIG_RFT, RIG_BACKEND_RFT }, \
+		{ RIG_KIT, RIG_BACKEND_KIT }, \
+		{ RIG_TUNER, RIG_BACKEND_TUNER }, \
 		{ 0, NULL }, /* end */  \
 }
 
