@@ -2,7 +2,7 @@
  *  Hamlib Kenwood backend - main file
  *  Copyright (c) 2000-2004 by Stephane Fillod and others
  *
- *	$Id: kenwood.c,v 1.73 2004/02/14 16:50:53 f4dwv Exp $
+ *	$Id: kenwood.c,v 1.78 2004/09/26 08:35:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -92,6 +92,7 @@ static const struct kenwood_id_string kenwood_id_string_list[] = {
 	{ RIG_MODEL_THD7A,  "TH-D7" },
 	{ RIG_MODEL_THD7AG, "TH-D7G" },
 	{ RIG_MODEL_TMD700, "TM-D700" },
+	{ RIG_MODEL_TMV7,   "TM-V7" },
 	{ RIG_MODEL_THF6A, "TH-F6" },
 	{ RIG_MODEL_THF7E, "TH-F7" },
 	{ RIG_MODEL_THG71, "TH-G71" },
@@ -139,15 +140,16 @@ kenwood_transaction (RIG *rig, const char *cmdstr, int cmd_len,
     int retval;
     const char *cmdtrm = EOM_KEN;  /* Default Command/Reply termination char */
     int retry_read = 0;
-#define MAX_RETRY_READ  32
 
     rs = &rig->state;
     rs->hold_decode = 1;
 
-	serial_flush(&rs->rigport);
-
     cmdtrm = cmd_trm(rig);
 
+transaction_write:
+
+    serial_flush(&rs->rigport);
+
     if (cmdstr) {
         retval = write_block(&rs->rigport, cmdstr, strlen(cmdstr));
         if (retval != RIG_OK)
@@ -167,16 +169,18 @@ kenwood_transaction (RIG *rig, const char *cmdstr, int cmd_len,
 transaction_read:
     memset(data,0,*datasize);
     retval = read_string(&rs->rigport, data, *datasize, cmdtrm, strlen(cmdtrm));
-    if (retval < 0)
-        	goto transaction_quit;
-	else
-		*datasize = retval;
+    if (retval < 0) {
+        if (retry_read++ < rig->state.rigport.retry)
+            goto transaction_write;
+        goto transaction_quit;
+    }	else
+  	    *datasize = retval;
 
     /* Check that command termination is correct */
-    if (!strchr(cmdtrm, data[strlen(data)])) {
-        if (retry_read++ < MAX_RETRY_READ)
-            goto transaction_read;
+    if (strchr(cmdtrm, data[strlen(data)-1])==NULL) {
         rig_debug(RIG_DEBUG_ERR, "%s: Command is not correctly terminated '%s'\n", __FUNCTION__, data);
+        if (retry_read++ < rig->state.rigport.retry)
+            goto transaction_write;
         retval = -RIG_EPROTO;
         goto transaction_quit;
     }
@@ -212,9 +216,10 @@ transaction_read:
           *       to the decoder for callback. That way we don't ignore
           *       any commands.
           */
-        if (retry_read++ < MAX_RETRY_READ)
-            goto transaction_read;
         rig_debug(RIG_DEBUG_ERR, "%s: Unexpected reply '%s'\n", __FUNCTION__, data);
+        if (retry_read++ < rig->state.rigport.retry)
+            goto transaction_write;
+
         retval =  -RIG_EPROTO;
         goto transaction_quit;
     }
@@ -236,16 +241,12 @@ int kenwood_set_vfo(RIG *rig, vfo_t vfo)
 		int cmd_len, ack_len, retval;
 		char vfo_function;
 
-			/*
-			 * FIXME: vfo==RIG_VFO_CURR
-			 */
-
 		switch (vfo) {
 		case RIG_VFO_VFO:
 		case RIG_VFO_A: vfo_function = '0'; break;
 		case RIG_VFO_B: vfo_function = '1'; break;
 		case RIG_VFO_MEM: vfo_function = '2'; break;
-		/* TODO : case RIG_VFO_C: */ 
+		case RIG_VFO_CURR: return RIG_OK;
 		default: 
 			rig_debug(RIG_DEBUG_ERR,"kenwood_set_vfo: unsupported VFO %d\n",
 								vfo);
@@ -349,77 +350,6 @@ int kenwood_get_vfo(RIG *rig, vfo_t *vfo)
 }
 
 
-/*
- * kenwood_old_set_vfo
- * Assumes rig!=NULL
- * for TS-940, TS-811, TS-711 and TS-440
- */
-int kenwood_old_set_vfo(RIG *rig, vfo_t vfo)
-{
-		unsigned char cmdbuf[16], ackbuf[16];
-		int cmd_len, ack_len, retval;
-		char vfo_function;
-
-			/*
-			 * FIXME: vfo==RIG_VFO_CURR
-			 */
-
-		switch (vfo) {
-		case RIG_VFO_VFO:
-		case RIG_VFO_A: vfo_function = '0'; break;
-		case RIG_VFO_B: vfo_function = '1'; break;
-		case RIG_VFO_MEM: vfo_function = '2'; break;
-		/* TODO : case RIG_VFO_C: */ 
-		default: 
-			rig_debug(RIG_DEBUG_ERR,"kenwood_set_vfo: unsupported VFO %d\n",
-								vfo);
-			return -RIG_EINVAL;
-		}
-
-		cmd_len = sprintf(cmdbuf, "FN%c%s", vfo_function, cmd_trm(rig));
-
-		ack_len = 0;
-		retval = kenwood_transaction (rig, cmdbuf, cmd_len, ackbuf, &ack_len);
-		return retval;
-}
-
-/*
- * kenwood_old_get_vfo
- * Assumes rig!=NULL, !vfo
- * for TS-940, TS-811, TS-711 and TS-440
- */
-int kenwood_old_get_vfo(RIG *rig, vfo_t *vfo)
-{
-		unsigned char vfobuf[50];
-		int vfo_len, retval;
-
-
-		/* query RX VFO */
-		vfo_len = 50;
-		retval = kenwood_transaction (rig, "FN;", 3, vfobuf, &vfo_len);
-		if (retval != RIG_OK)
-			return retval;
-
-		if (vfo_len != 4 || vfobuf[1] != 'N') {
-			rig_debug(RIG_DEBUG_ERR,"%s: unexpected answer %s, "
-				"len=%d\n", __FUNCTION__, vfobuf, vfo_len);
-			return -RIG_ERJCTED;
-		}
-
-		/* TODO: replace 0,1,2,.. constants by defines */
-		switch (vfobuf[2]) {
-		case '0': *vfo = RIG_VFO_A; break;
-		case '1': *vfo = RIG_VFO_B; break;
-		case '2': *vfo = RIG_VFO_MEM; break;
-		default: 
-			rig_debug(RIG_DEBUG_ERR,"%s: unsupported VFO %c\n",
-						__FUNCTION__, vfobuf[2]);
-			return -RIG_EPROTO;
-		}
-		return RIG_OK;
-}
-
-
 /*
  * kenwood_set_freq
  * Assumes rig!=NULL
@@ -429,17 +359,12 @@ int kenwood_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 		unsigned char freqbuf[16], ackbuf[16];
 		int freq_len, ack_len, retval;
 		char vfo_letter;
+		vfo_t	tvfo;
 
-			/*
-			 * better FIXME: vfo==RIG_VFO_CURR
-			 */
-		if (vfo == RIG_VFO_CURR) {
-			retval = kenwood_get_vfo(rig, &vfo);
-			if (retval != RIG_OK)
-					return retval;
-		}
-
-		switch (vfo) {
+        	if(vfo==RIG_VFO_CURR) tvfo=rig->state.current_vfo;
+        	else tvfo=vfo;
+                                                                                         
+		switch (tvfo) {
 		case RIG_VFO_A: vfo_letter = 'A'; break;
 		case RIG_VFO_B: vfo_letter = 'B'; break;
 		case RIG_VFO_C: vfo_letter = 'C'; break;
@@ -467,17 +392,12 @@ int kenwood_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 		int cmd_len, freq_len, retval;
 		char vfo_letter;
 		long long f;
+		vfo_t	tvfo;
 
-			/*
-			 * better FIXME: vfo==RIG_VFO_CURR
-			 */
-		if (vfo == RIG_VFO_CURR) {
-			retval = kenwood_get_vfo(rig, &vfo);
-			if (retval != RIG_OK)
-				return retval;
-		}
-
-		switch (vfo) {
+        	if(vfo==RIG_VFO_CURR) tvfo=rig->state.current_vfo;
+        	else tvfo=vfo;
+                                                                                         
+		switch (tvfo) {
 		case RIG_VFO_A: vfo_letter = 'A'; break;
 		case RIG_VFO_B: vfo_letter = 'B'; break;
 		case RIG_VFO_C: vfo_letter = 'C'; break;
@@ -539,7 +459,7 @@ int kenwood_set_rit(RIG * rig, vfo_t vfo, shortfreq_t rit)
 	
 	info_len = 0;
         if (rit == 0)
-        return kenwood_transaction(rig, "RC;", 3, infobuf, &info_len);
+        	return kenwood_transaction(rig, "RC;", 3, infobuf, &info_len);
 
         if (rit > 0)
                 c = 'U';
@@ -571,6 +491,15 @@ int kenwood_set_xit(RIG * rig, vfo_t vfo, shortfreq_t rit)
         return kenwood_set_rit(rig, vfo, rit);
 }
 
+int kenwood_scan(RIG * rig, vfo_t vfo, scan_t scan, int ch)
+{
+	unsigned char ackbuf[16];
+	int ack_len = 0;
+
+	return kenwood_transaction (rig, scan==RIG_SCAN_STOP? "SC0;":"SC1;", 4, 
+						ackbuf, &ack_len);
+}
+
 
 /*
  * kenwood_set_mode
@@ -801,7 +730,6 @@ int kenwood_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 			else if (agclevel <= 255) val->i = 3;
 			return ret;
 
-		case RIG_LEVEL_SQLSTAT:
 		case RIG_LEVEL_PREAMP:
 		case RIG_LEVEL_IF:
 		case RIG_LEVEL_APF:
@@ -1081,6 +1009,7 @@ int kenwood_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 		return RIG_OK;
 }
 
+
 /*
  * kenwood_set_ptt
  * Assumes rig!=NULL
@@ -1479,58 +1408,6 @@ DECLARE_PROBERIG_BACKEND(kenwood)
 }
 
 
-/* kenwood_init
- *
- * Basically, it sets up *priv
- * REM: serial port is already open (rig->state.rigport.fd)
- */
-int kenwood_init(RIG *rig)
-{
-    const struct rig_caps *caps;
-    const struct kenwood_priv_caps *priv_caps;
-    rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __FUNCTION__);
-
-    if (!rig || !rig->caps)
-        return -RIG_EINVAL;
-
-    caps = rig->caps;
-    if (!caps->priv)
-        return -RIG_ECONF;
-
-    priv_caps = (const struct kenwood_priv_caps *) caps->priv;
-
-#if 0   /* No private data for Kenwood backends */
-    priv = (struct kenwood_priv_data *)malloc(sizeof(struct kenwood_priv_data));
-    if (!priv) {
-        /* whoops! memory shortage! */
-        return -RIG_ENOMEM;
-    }
-
-    rig->state.priv = (void *)priv;
-    /* Assign default values */
-    priv->dummy = -1;  // placeholder for real entries.
-#endif
-
-    return RIG_OK;
-}
-
-/* kenwood_cleanup
- * the serial port is closed by the frontend
- */
-int kenwood_cleanup(RIG *rig)
-{
-    rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __FUNCTION__);
-
-    if (!rig)
-        return -RIG_EINVAL;
-
-    if (rig->state.priv)
-        free(rig->state.priv);
-    rig->state.priv = NULL;
-
-    return RIG_OK;
-}
-
 /*
  * initrigs_kenwood is called by rig_backend_load
  */
@@ -1541,28 +1418,30 @@ DECLARE_INITRIG_BACKEND(kenwood)
 		rig_register(&ts950sdx_caps);
 		rig_register(&ts50s_caps);
 		rig_register(&ts140_caps);
-		rig_register(&ts440_caps);
 		rig_register(&ts450s_caps);
 		rig_register(&ts570d_caps);
 		rig_register(&ts570s_caps);
 		rig_register(&ts680s_caps);
 		rig_register(&ts690s_caps);
-		rig_register(&ts711_caps);
-		rig_register(&ts811_caps);
 		rig_register(&ts790_caps);
 		rig_register(&ts850_caps);
 		rig_register(&ts870s_caps);
 		rig_register(&ts930_caps);
-		rig_register(&ts940_caps);
 		rig_register(&ts2000_caps);
 		rig_register(&k2_caps);
 
+		rig_register(&ts440_caps);
+		rig_register(&ts940_caps);
+		rig_register(&ts711_caps);
+		rig_register(&ts811_caps);
+		rig_register(&r5000_caps);
+
 		rig_register(&tmd700_caps);
 		rig_register(&thd7a_caps);
 		rig_register(&thf7e_caps);
 		rig_register(&thg71_caps);
+		rig_register(&tmv7_caps);
 
 		return RIG_OK;
 }
 
-
