@@ -2,7 +2,7 @@
  *  Hamlib Kenwood backend - TH handheld primitives
  *  Copyright (c) 2001-2003 by Stephane Fillod
  *
- *	$Id: th.c,v 1.17 2004/01/15 22:03:18 fillods Exp $
+ *	$Id: th.c,v 1.22 2004/11/11 17:51:53 f4dwv Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -368,11 +368,12 @@ th_set_vfo (RIG *rig, vfo_t vfo)
 int
 th_get_vfo (RIG *rig, vfo_t *vfo)
 {
-    char ackbuf[ACKBUF_LEN];
-    int retval,ack_len=ACKBUF_LEN;
+    char cmdbuf[16], ackbuf[ACKBUF_LEN],vfoc;
+    int retval,ack_len;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __FUNCTION__);
 
+    ack_len=ACKBUF_LEN;
     retval = kenwood_transaction (rig, "BC" EOM, 3, ackbuf, &ack_len);
     if (retval != RIG_OK)
         return retval;
@@ -382,7 +383,8 @@ th_get_vfo (RIG *rig, vfo_t *vfo)
         return -RIG_ERJCTED;
     }
 
-    switch (ackbuf[3]) {
+    vfoc=ackbuf[3];
+    switch (vfoc) {
         case '0': *vfo = RIG_VFO_A; break;
         case '1': *vfo = RIG_VFO_B; break;
         default:
@@ -390,7 +392,29 @@ th_get_vfo (RIG *rig, vfo_t *vfo)
             return -RIG_EVFO;
     }
 
-	return RIG_OK;
+    sprintf(cmdbuf,"VMC %c" EOM,vfoc);
+    ack_len=ACKBUF_LEN;
+    retval = kenwood_transaction (rig, cmdbuf, strlen(cmdbuf), ackbuf, &ack_len);
+    if (retval != RIG_OK)
+        return retval;
+
+    if (ack_len < 8 ) {
+        rig_debug(RIG_DEBUG_ERR, "%s: Unexpected reply '%s'\n", __FUNCTION__, ackbuf);
+        return -RIG_ERJCTED;
+    }
+    switch(ackbuf[6]) {
+	case '0' :
+	case '1' :
+		break;
+	case '2' :
+		*vfo = RIG_VFO_MEM;
+		break;
+        default:
+            rig_debug(RIG_DEBUG_ERR, "%s: Unexpected VFO value '%c'\n", __FUNCTION__, ackbuf[6]);
+            return -RIG_EVFO;
+     }
+
+     return RIG_OK;
 }
 
 
@@ -440,12 +464,12 @@ th_get_trn (RIG *rig, int *trn)
 	return RIG_OK;
 }
 
+
 /*
  * th_get_kenwood_func
  * Assumes rig!=NULL, status!=NULL
  */
-int
-th_get_kenwood_func (RIG *rig, const char *cmd, int *status)
+static int th_get_kenwood_func (RIG *rig, const char *cmd, int *status)
 {
     char ackbuf[ACKBUF_LEN];
     int retval,ack_len=ACKBUF_LEN;
@@ -479,12 +503,8 @@ th_get_func (RIG *rig, vfo_t vfo, setting_t func, int *status)
 
     /* FIXME: What about the VFO? */
 
-    /* Optimize:
-     *   sort the switch cases with the most frequent first
-     */
     switch (func) {
-        case RIG_FUNC_MON:  /* which one? */
-        case RIG_FUNC_SQL:
+        case RIG_FUNC_MON:
             return th_get_kenwood_func(rig, "MON" EOM, status);
         case RIG_FUNC_TONE:
             return th_get_kenwood_func(rig, "TO" EOM, status);
@@ -498,24 +518,86 @@ th_get_func (RIG *rig, vfo_t vfo, setting_t func, int *status)
             return th_get_kenwood_func(rig, "AIP" EOM, status);
         case RIG_FUNC_LOCK:
             return th_get_kenwood_func(rig, "LK" EOM, status);
+        default:
+            rig_debug(RIG_DEBUG_ERR,"%s: Unsupported function %#x", __FUNCTION__, func);
+            return -RIG_EINVAL;
+    }
+    return RIG_OK;
+}
 
-        case RIG_FUNC_FAGC:
-        case RIG_FUNC_NB:
-        case RIG_FUNC_COMP:
-        case RIG_FUNC_VOX:
-        case RIG_FUNC_SBKIN:
-        case RIG_FUNC_FBKIN:
-        case RIG_FUNC_ANF:
-        case RIG_FUNC_NR:
-        case RIG_FUNC_APF:
-        case RIG_FUNC_MN:
-        case RIG_FUNC_RNF:
-        case RIG_FUNC_MUTE:
-        case RIG_FUNC_VSC:
-        case RIG_FUNC_ABM:
-        case RIG_FUNC_BC:
-        case RIG_FUNC_MBC:
-            return -RIG_ENAVAIL;
+/* --------------------------------------------------------------------- */
+static int th_tburst(RIG *rig, vfo_t vfo, int status)
+{
+    char ackbuf[ACKBUF_LEN];
+    int retval,ack_len=ACKBUF_LEN;
+
+    if(status==1) {
+    retval = kenwood_transaction(rig, "TT"EOM, 3, ackbuf, &ack_len);
+        if (retval != RIG_OK)
+        	return retval;
+
+	return RIG_OK;
+    }
+    if(status==0) {
+	return rig_set_ptt(rig,vfo,RIG_PTT_OFF);
+    }
+    return -RIG_EINVAL;
+}
+
+/*
+ * th_set_kenwood_func
+ * Assumes rig!=NULL, status!=NULL
+ */
+static int th_set_kenwood_func (RIG *rig, const char *cmd, int status)
+{
+    char trbuf[16], ackbuf[ACKBUF_LEN];
+    int retval,ack_len=ACKBUF_LEN;
+
+    rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __FUNCTION__);
+
+    strncpy(trbuf,cmd,16);
+    strncat(trbuf,(status)?" 1":" 0",16);
+    strncat(trbuf,EOM,16);
+    retval = kenwood_transaction (rig, cmd, strlen(cmd), ackbuf, &ack_len);
+    if (retval != RIG_OK)
+        return retval;
+
+    if (ack_len < 4 ) {
+        rig_debug(RIG_DEBUG_ERR, "%s: Unexpected reply '%s'\n", __FUNCTION__, ackbuf);
+        return -RIG_ERJCTED;
+	}
+	return RIG_OK;
+};
+
+
+/*
+ * th_get_func
+ * Assumes rig!=NULL, status!=NULL
+ */
+int
+th_set_func (RIG *rig, vfo_t vfo, setting_t func, int status)
+{
+    rig_debug(RIG_DEBUG_TRACE, "%s: called (0x%04x)\n", __FUNCTION__, func);
+
+    /* FIXME: What about the VFO? */
+
+    switch (func) {
+        case RIG_FUNC_MON:
+            return th_set_kenwood_func(rig, "MON", status);
+        case RIG_FUNC_TONE:
+            return th_set_kenwood_func(rig, "TO", status);
+        case RIG_FUNC_TSQL:
+            return th_set_kenwood_func(rig, "CT", status);
+        case RIG_FUNC_REV:
+            return th_set_kenwood_func(rig, "REV", status);
+        case RIG_FUNC_ARO:
+            return th_set_kenwood_func(rig, "ARO", status);
+        case RIG_FUNC_AIP:
+            return th_set_kenwood_func(rig, "AIP", status);
+        case RIG_FUNC_LOCK:
+            return th_set_kenwood_func(rig, "LK", status);
+        case RIG_FUNC_TBURST:
+            return th_tburst(rig, vfo, status);
         default:
             rig_debug(RIG_DEBUG_ERR,"%s: Unsupported function %#x", __FUNCTION__, func);
             return -RIG_EINVAL;
@@ -588,7 +670,7 @@ th_get_level (RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 				return retval;
 
             retval = sscanf(ackbuf, "SM %d,%d", &v, &l);
-            if (retval != 2 || l < 0 || l > 5) {
+            if (retval != 2 || l < rig->caps->level_gran[LVL_RAWSTR].min.i || l > rig->caps->level_gran[LVL_RAWSTR].max.i) {
                 rig_debug(RIG_DEBUG_ERR, "%s: Unexpected reply '%s'\n", __FUNCTION__, ackbuf);
                 return -RIG_ERJCTED;
             }
@@ -602,30 +684,46 @@ th_get_level (RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 		if (retval != RIG_OK)
 			return retval;
 
-            retval = sscanf(ackbuf, "SQ %d,%d", &v, &l);
-            if (retval != 2 || l < 0 || l > 5) {
+            retval = sscanf(ackbuf, "SQ %d,%x", &v, &l);
+            if (retval != 2 || l < rig->caps->level_gran[LVL_SQL].min.i || l > rig->caps->level_gran[LVL_SQL].max.i) {
                 rig_debug(RIG_DEBUG_ERR, "%s: Unexpected reply '%s'\n", __FUNCTION__, ackbuf);
                 return -RIG_ERJCTED;
             }
 
             /* range [0.0 ... 1.0] */
-            val->f = l / 5.0;
+            val->f = (float)(l-rig->caps->level_gran[LVL_SQL].min.i) / (float)(rig->caps->level_gran[LVL_SQL].max.i-rig->caps->level_gran[LVL_SQL].min.i);
 		break;
 
-        case RIG_LEVEL_RFPOWER:
-            sprintf(lvlbuf, "PC 0" EOM); /* only VHF power ... */
+        case RIG_LEVEL_AF:
+            sprintf(lvlbuf, "AG %c" EOM, vch);
             retval = kenwood_transaction (rig, lvlbuf, strlen(lvlbuf), ackbuf, &ack_len);
 		if (retval != RIG_OK)
 			return retval;
 
-            retval = sscanf(ackbuf, "PC 0,%d", &l);
+            retval = sscanf(ackbuf, "AG %d,%x", &v, &l);
+            if (retval != 2 || l < rig->caps->level_gran[LVL_AF].min.i || l > rig->caps->level_gran[LVL_AF].max.i) {
+                rig_debug(RIG_DEBUG_ERR, "%s: Unexpected reply '%s'\n", __FUNCTION__, ackbuf);
+                return -RIG_ERJCTED;
+            }
+
+            /* range [0.0 ... 1.0] */
+            val->f = (float)(l-rig->caps->level_gran[LVL_AF].min.i) / (float)(rig->caps->level_gran[LVL_AF].max.i-rig->caps->level_gran[LVL_AF].min.i);
+		break;
+
+        case RIG_LEVEL_RFPOWER:
+            sprintf(lvlbuf, "PC %c" EOM,vch); 
+            retval = kenwood_transaction (rig, lvlbuf, strlen(lvlbuf), ackbuf, &ack_len);
+		if (retval != RIG_OK)
+			return retval;
+
+            retval = sscanf(ackbuf, "PC %d,%d", &v, &l);
             if (retval != 1 || l < 0 || l > 3) {
                 rig_debug(RIG_DEBUG_ERR, "%s: Unexpected reply '%s'\n", __FUNCTION__, ackbuf);
                 return -RIG_ERJCTED;
             }
 
             /* range [0.0 ... 1.0] */
-            val->f = (3.0-l) / 3.0;
+            val->f = (float)(l-rig->caps->level_gran[LVL_RFPOWER].min.i) / (float)(rig->caps->level_gran[LVL_RFPOWER].max.i-rig->caps->level_gran[LVL_AF].min.i);
 		break;
         default:
             rig_debug(RIG_DEBUG_ERR,"%s: Unsupported Level %d", __FUNCTION__, level);
@@ -657,13 +755,25 @@ int th_set_level (RIG *rig, vfo_t vfo, setting_t level, value_t val)
             return -RIG_EVFO;
 	}
 
-    if(level!=RIG_LEVEL_RFPOWER)
+    switch(level) {
+
+	case RIG_LEVEL_RFPOWER :
+	    sprintf(lvlbuf, "PC %c,%01d" EOM, vch,(int)(val.f*(rig->caps->level_gran[LVL_RFPOWER].max.i-rig->caps->level_gran[LVL_RFPOWER].min.i))+rig->caps->level_gran[LVL_RFPOWER].min.i);
+	    retval = kenwood_transaction (rig, lvlbuf, strlen(lvlbuf), ackbuf, &ack_len);
+	    return retval;
+	case RIG_LEVEL_SQL :
+	    sprintf(lvlbuf, "SQ %c,%02x" EOM, vch,(int)(val.f*(rig->caps->level_gran[LVL_SQL].max.i-rig->caps->level_gran[LVL_SQL].min.i))+rig->caps->level_gran[LVL_SQL].min.i);
+	    retval = kenwood_transaction (rig, lvlbuf, strlen(lvlbuf), ackbuf, &ack_len);
+	    return retval;
+	case RIG_LEVEL_AF :
+	    sprintf(lvlbuf, "AG %c,%02x" EOM, vch,(int)(val.f*32.0));
+	    retval = kenwood_transaction (rig, lvlbuf, strlen(lvlbuf), ackbuf, &ack_len);
+	    return retval;
+        default:
+            rig_debug(RIG_DEBUG_ERR,"%s: Unsupported Level %d", __FUNCTION__, level);
             return -RIG_EINVAL;
-
-    sprintf(lvlbuf, "PC 0,%d" EOM, 3-(int)(val.f*3.0)); /* only VHF power ... */
-    retval = kenwood_transaction (rig, lvlbuf, strlen(lvlbuf), ackbuf, &ack_len);
-
-    return retval;
+    }
+    return RIG_OK;
 }
 
 #ifndef RIG_TONEMAX
@@ -805,12 +915,15 @@ th_get_mem(RIG *rig, vfo_t vfo, int *ch)
 {
 	unsigned char *membuf, ackbuf[ACKBUF_LEN];
 	int retval,ack_len=ACKBUF_LEN;
-	vfo_t tvfo;
+	vfo_t tvfo,cvfo;
 
 	rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __FUNCTION__);
 
-	if(vfo==RIG_VFO_CURR) tvfo=rig->state.current_vfo;
-	else tvfo=vfo;
+	cvfo=rig->state.current_vfo;
+	if(vfo==RIG_VFO_CURR)
+		 tvfo=cvfo;
+	else
+		 tvfo=vfo;
 
 	switch (tvfo) {
 	  case RIG_VFO_VFO:
@@ -843,6 +956,10 @@ th_get_mem(RIG *rig, vfo_t vfo, int *ch)
 	ackbuf[8]='\0';
         *ch = atoi(&ackbuf[5]);
 
+	retval= rig_set_vfo(rig,cvfo);
+	if (retval != RIG_OK)
+		return retval;
+
 	return RIG_OK;
 }
 
@@ -872,6 +989,52 @@ th_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 	return RIG_OK;
 }
 
+int
+th_set_powerstat(RIG *rig, powerstat_t status)
+{
+        unsigned char *membuf;
+        int retval;
+
+        rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __FUNCTION__);
+
+        switch(status) {
+         case RIG_POWER_ON :
+                membuf="PS 1" EOM;
+                break;
+         case RIG_POWER_OFF :
+                membuf="PS 0" EOM;
+                break;
+         default:
+                return -RIG_EINVAL;
+        }
+
+        retval = kenwood_transaction(rig, membuf, strlen(membuf), NULL, NULL);
+        if (retval != RIG_OK)
+                return retval;
+
+	return RIG_OK;
+}
+
+int th_get_powerstat(RIG *rig, powerstat_t *status)
+{
+                unsigned char pwrbuf[50];
+                int pwr_len = 50, retval;
+                                                                                                                            
+                retval = kenwood_transaction (rig, "PS;", 3, pwrbuf, &pwr_len);
+                if (retval != RIG_OK)
+                        return retval;
+                                                                                                                            
+                if (pwr_len != 4) {
+                                rig_debug(RIG_DEBUG_ERR,"kenwood_get_powerstat: wrong answer "
+                                                                "len=%d\n", pwr_len);
+                                return -RIG_ERJCTED;
+                }
+                *status = pwrbuf[2] == '0' ? RIG_POWER_OFF : RIG_POWER_ON;
+                                                                                                                            
+                return RIG_OK;
+}
+                                                                                                                            
+
 int th_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
         unsigned char *membuf, ackbuf[ACKBUF_LEN];
@@ -935,6 +1098,9 @@ int th_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 		case RIG_OP_DOWN:
                 	membuf="DW" EOM;
                		break;
+		case RIG_OP_TO_VFO:
+                	membuf="MSH" EOM;
+               		break;
 		default:
                 	return -RIG_EINVAL;
 	}
@@ -944,3 +1110,223 @@ int th_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
                 return retval;
         return RIG_OK;
 }
+
+/* get and set channel tested on thg71 and tmv7	*/
+/* must work on other th and tm kenwood rigs	*/
+/* Beware : special numbering scheme :		*/
+/* 0-199 : normal memories			*/
+/* 200-209 : scan lower limit memories L	*/
+/* 210-219 : scan upper limit memories U	*/
+/* 220     : Priority channel 			*/
+/* 221-222 : Call channel 			*/
+/* 223-231 : Band vfo mem 			*/
+/* --------------------------------------------------------------------- */
+int th_get_channel(RIG *rig, channel_t *chan)
+{
+    char membuf[64],ackbuf[ACKBUF_LEN];
+    int retval,ack_len;
+    freq_t freq,offset;
+    char req[16],scf[128];
+    int step, shift, rev, tone, ctcss, tonefq, ctcssfq;
+
+    if(chan->channel_num<200)
+    	sprintf(req,"MR 0,0,%03d",chan->channel_num);
+    else
+    if(chan->channel_num<210) {
+    	sprintf(req,"MR 0,0,L%01d",chan->channel_num-200);
+        sprintf(chan->channel_desc,"L%01d",chan->channel_num-200);
+    } else
+    if(chan->channel_num<220) {
+   	sprintf(req,"MR 0,0,U%01d",chan->channel_num-210);
+        sprintf(chan->channel_desc,"U%01d",chan->channel_num-210);
+    } else
+    if(chan->channel_num==220) {
+   	sprintf(req,"MR 0,0,PR");
+        sprintf(chan->channel_desc,"Pr");
+    } else
+    if(chan->channel_num<223) {
+    	sprintf(req,"CR 0,%01d",chan->channel_num-221);
+        if(chan->channel_num==221) sprintf(chan->channel_desc,"Call V");
+        if(chan->channel_num==222) sprintf(chan->channel_desc,"Call U");
+    } else
+    if(chan->channel_num<232) {
+    	sprintf(req,"VR %01d",chan->channel_num-222);
+        sprintf(chan->channel_desc,"BAND %01d",chan->channel_num-222);
+    } else
+	return -RIG_EINVAL;
+
+    sprintf(membuf,"%s"EOM,req);
+    ack_len=ACKBUF_LEN;
+    retval = kenwood_transaction(rig, membuf, strlen(membuf), ackbuf, &ack_len);
+        if (retval != RIG_OK)
+        	return retval;
+
+    strcpy(scf,req);
+    strcat(scf,",%"FREQFMT",%d,%d,%d,%d,%d,,%d,,%d,%"FREQFMT);
+    retval = sscanf(ackbuf, scf,
+                    &freq, &step, &shift, &rev, &tone,
+                    &ctcss, &tonefq, &ctcssfq, &offset);
+
+    chan->freq=freq;
+    chan->vfo=RIG_VFO_MEM;
+    chan->tuning_step=rig->state.tuning_steps[step].ts;
+    if(freq <MHz(136) )  {
+		chan->mode=RIG_MODE_AM;
+		chan->width=kHz(9);
+    } else {
+		chan->mode=RIG_MODE_FM;
+		chan->width=kHz(12);
+    }
+    switch(shift) {
+	case 0 :
+		chan->rptr_shift=RIG_RPT_SHIFT_NONE;
+		break;
+	case 1 :
+		chan->rptr_shift=RIG_RPT_SHIFT_PLUS;
+		break;
+	case 2 :
+		chan->rptr_shift=RIG_RPT_SHIFT_MINUS;
+		break;
+    }
+    chan->rptr_offs=offset;
+
+    if(tone)
+	 chan->ctcss_tone=rig->caps->ctcss_list[tonefq==1?0:tonefq-2];
+    else
+	 chan->ctcss_tone=0;
+    if(ctcss)
+	 chan->ctcss_sql=rig->caps->ctcss_list[ctcssfq==1?0:ctcssfq-2];
+    else
+	 chan->ctcss_sql=0;
+
+    chan->tx_freq=RIG_FREQ_NONE;
+    if(chan->channel_num<223 && offset==0) {
+	req[5]='1';
+        sprintf(membuf,"%s"EOM,req);
+        ack_len=ACKBUF_LEN;
+    	retval = kenwood_transaction(rig, membuf, strlen(membuf), ackbuf, &ack_len);
+        if (retval == RIG_OK) {
+    		strcat(req,",%"FREQFMT",%d");
+    		retval = sscanf(ackbuf, req, &freq, &step);
+		chan->tx_freq=freq;
+	}
+    }
+
+    if(chan->channel_num<200) {
+    	sprintf(membuf,"MNA 0,%03d"EOM,chan->channel_num);
+        ack_len=ACKBUF_LEN;
+    	retval = kenwood_transaction(rig, membuf, strlen(membuf), ackbuf, &ack_len);
+        if (retval != RIG_OK)
+        	return retval;
+        memcpy(chan->channel_desc,&ackbuf[10],7);
+    }
+
+    return RIG_OK;
+}
+
+/* --------------------------------------------------------------------- */
+int th_set_channel(RIG *rig, const channel_t *chan)
+{
+    char membuf[ACKBUF_LEN],ackbuf[ACKBUF_LEN];
+    int retval,ack_len;
+    char req[64];
+    long long freq,offset;   
+    int chn, step, shift, tone, ctcss, tonefq, ctcssfq;
+
+    chn=chan->channel_num;
+    freq=(long long)chan->freq;
+
+    for(step=0; rig->state.tuning_steps[step].ts!=0;step++)
+	if(chan->tuning_step==rig->state.tuning_steps[step].ts) break;
+
+    switch(chan->rptr_shift) {
+	case RIG_RPT_SHIFT_NONE :
+		shift=0;
+		break;
+	case  RIG_RPT_SHIFT_PLUS:
+		shift=1;
+		break;
+	case RIG_RPT_SHIFT_MINUS:
+		shift=2;
+		break;
+        default:
+            rig_debug(RIG_DEBUG_ERR, "%s: not supported shift\n", __FUNCTION__);
+            return -RIG_EINVAL;
+    }
+    offset=chan->rptr_offs;
+    
+    if(chan->ctcss_tone==0) {
+	 tone=0;tonefq=9;
+    } else {
+	 tone=1;
+    	for (tonefq = 0; rig->caps->ctcss_list[tonefq] != 0 && tonefq < RIG_TONEMAX; tonefq++) {
+		if (rig->caps->ctcss_list[tonefq] == chan->ctcss_tone)
+			break;
+	}
+	tonefq=tonefq==0?1:tonefq+2;
+    }
+    if(chan->ctcss_sql==0) {
+	ctcss=0;ctcssfq=9;
+    } else {
+	 ctcss=1;
+    	for (ctcssfq = 0; rig->caps->ctcss_list[ctcssfq] != 0 && ctcssfq < RIG_TONEMAX; ctcssfq++) {
+		if (rig->caps->ctcss_list[ctcssfq] == chan->ctcss_sql)
+			break;
+	}
+	 ctcssfq=ctcssfq==0?1:ctcssfq+2;
+    }
+
+    if(chan->channel_num<200)
+    	sprintf(req,"MW 0,0,%03d",chan->channel_num);
+    else
+    if(chan->channel_num<210) {
+    	sprintf(req,"MW 0,0,L%01d",chan->channel_num-200);
+    } else
+    if(chan->channel_num<220) {
+   	sprintf(req,"MW 0,0,U%01d",chan->channel_num-210);
+    } else
+    if(chan->channel_num==220) {
+   	sprintf(req,"MW 0,0,PR");
+    } else
+    if(chan->channel_num<223) {
+    	sprintf(req,"CW 0,%01d",chan->channel_num-221);
+    } else
+    if(chan->channel_num<232) {
+    	sprintf(req,"VW %01d",chan->channel_num-222);
+    } else
+	return -RIG_EINVAL;
+
+    if(chan->channel_num<=220)
+    sprintf(membuf, "%s,%011lld,%01d,%01d,0,%01d,%01d,,%02d,,%02d,%09lld,0"EOM,
+                    req,(long long)freq, step, shift, tone,
+                    ctcss, tonefq, ctcssfq, (long long)offset);
+    else
+    sprintf(membuf, "%s,%011lld,%01d,%01d,0,%01d,%01d,,%02d,,%02d,%09lld"EOM,
+                    req, (long long)freq, step, shift, tone,
+                    ctcss, tonefq, ctcssfq, (long long)offset);
+
+    ack_len=ACKBUF_LEN;
+    retval = kenwood_transaction(rig, membuf, strlen(membuf), ackbuf, &ack_len);
+        if (retval != RIG_OK)
+        	return retval;
+
+    if(chan->channel_num<223 && chan->tx_freq!=RIG_FREQ_NONE) {
+	req[5]='1';
+    	sprintf(membuf, "%s,%011lld,%01d"EOM, req,(long long)chan->tx_freq, step);
+        ack_len=ACKBUF_LEN;
+    	retval = kenwood_transaction(rig, membuf, strlen(membuf), ackbuf, &ack_len);
+        if (retval != RIG_OK)
+        	return retval;
+    }
+
+    if(chan->channel_num<200) {
+    	ack_len=ACKBUF_LEN;
+    	sprintf(membuf,"MNA 0,%03d,%s"EOM,chan->channel_num,chan->channel_desc);
+    	retval = kenwood_transaction(rig, membuf, strlen(membuf), ackbuf, &ack_len);
+        if (retval != RIG_OK)
+        	return retval;
+    }
+
+    return RIG_OK;
+}
+
