@@ -2,7 +2,7 @@
  *  Hamlib Kenwood backend - TH handheld header
  *  Copyright (c) 2001-2003 by Stephane Fillod
  *
- *	$Id: th.h,v 1.5 2003/11/30 20:43:32 f4dwv Exp $
+ *	$Id: th.h,v 1.9 2004/11/11 17:51:53 f4dwv Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -21,6 +21,7 @@
  */
 #ifndef __TH_H__
 #define __TH_H__ 1
+#include "idx_builtin.h"
 
 extern int th_transaction (RIG *rig, const char *cmdstr, char *data, size_t datasize);
 extern int th_decode_event (RIG *rig);
@@ -32,6 +33,9 @@ extern int th_set_vfo(RIG *rig, vfo_t vfo);
 extern int th_get_vfo(RIG *rig, vfo_t *vfo);
 extern int th_set_trn(RIG *rig, int trn);
 extern int th_get_trn (RIG *rig, int *trn);
+extern int th_set_powerstat (RIG *rig, powerstat_t status);
+extern int th_get_powerstat (RIG *rig, powerstat_t *status);
+extern int th_set_func (RIG *rig, vfo_t vfo, setting_t func, int status);
 extern int th_get_func (RIG *rig, vfo_t vfo, setting_t func, int *status);
 extern int th_get_parm (RIG *rig, setting_t parm, value_t *val);
 extern int th_get_level (RIG *rig, vfo_t vfo, setting_t level, value_t *val);
@@ -44,7 +48,21 @@ extern int th_get_mem(RIG *rig, vfo_t vfo, int *ch);
 extern int th_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt);
 extern int th_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op);
 extern int th_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd);
+extern int th_get_channel(RIG *rig, channel_t *chan);
+extern int th_set_channel(RIG *rig, const channel_t *chan);
 
+#define TH_CHANNEL_CAPS \
+.freq=1,\
+.tx_freq=1,\
+.mode=1,\
+.width=1,\
+.tuning_step=1,\
+.rptr_shift=1,\
+.rptr_offs=1,\
+.ctcss_tone=1,\
+.ctcss_sql=1,\
+.channel_desc=1
+                                                                                
 
 #endif /* __TH_H__ */
 /* end of file */
