@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - TH-D7 description
- *  Copyright (c) 2000-2003 by Stephane Fillod
+ *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: thd7.c,v 1.10 2003/10/01 19:31:58 fillods Exp $
+ *	$Id: thd7.c,v 1.14 2004/09/26 08:35:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -51,7 +51,6 @@
 
 #define THD7_LEVEL_ALL (RIG_LEVEL_STRENGTH| \
                         RIG_LEVEL_SQL| \
-                        RIG_LEVEL_SQLSTAT| \
                         RIG_LEVEL_AF| \
                         RIG_LEVEL_RF|\
                         RIG_LEVEL_MICGAIN)
@@ -77,7 +76,7 @@ const struct rig_caps thd7a_caps = {
 .rig_model =  RIG_MODEL_THD7A,
 .model_name = "TH-D7A",
 .mfg_name =  "Kenwood",
-.version =  "0.1.1",
+.version =  "0.1.2",
 .copyright =  "LGPL",
 .status =  RIG_STATUS_ALPHA,
 .rig_type =  RIG_TYPE_HANDHELD|RIG_FLAG_APRS|RIG_FLAG_TNC|RIG_FLAG_DXCLUSTER,
@@ -101,7 +100,11 @@ const struct rig_caps thd7a_caps = {
 .has_set_level =  RIG_LEVEL_SET(THD7_LEVEL_ALL),
 .has_get_parm =  THD7_PARMS,
 .has_set_parm =  THD7_PARMS,    /* FIXME: parms */
-.level_gran =  {},                 /* FIXME: granularity */
+.level_gran = {
+        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 5 } },
+        [LVL_SQL] = { .min = { .i = 0 }, .max = { .i = 5 } },
+        [LVL_RFPOWER] = { .min = { .i = 3 }, .max = { .i = 0 } },
+},
 .parm_gran =  {},
 .ctcss_list =  kenwood38_ctcss_list,
 .dcs_list =  NULL,
@@ -116,11 +119,13 @@ const struct rig_caps thd7a_caps = {
 .bank_qty =   0,
 .chan_desc_sz =  0,
 
-
-.chan_list =  { {  1,  200, RIG_MTYPE_MEM },
-			 RIG_CHAN_END,
-		   },	/* FIXME: memory channel list: 200 memories */
-
+.chan_list =  {
+                {  1,  199, RIG_MTYPE_MEM , {TH_CHANNEL_CAPS}},  /* normal MEM */
+                {  200,219, RIG_MTYPE_EDGE , {TH_CHANNEL_CAPS}}, /* U/L MEM */
+                {  221,222, RIG_MTYPE_MEM , {TH_CHANNEL_CAPS}},  /* Call 0/1 */
+                RIG_CHAN_END,
+                   },
+                                                                                                    
 .rx_range_list1 =  { RIG_FRNG_END, },    /* FIXME: enter region 1 setting */
 .tx_range_list1 =  { RIG_FRNG_END, },
 .rx_range_list2 =  {
@@ -153,10 +158,6 @@ const struct rig_caps thd7a_caps = {
 		RIG_FLT_END,
 	},
 .priv =  (void *)&thd7_priv_caps,
-.rig_init =  kenwood_init,
-.rig_cleanup =  kenwood_cleanup,
-.rig_open =  NULL,
-.rig_close =  NULL,
 
 .set_freq =  th_set_freq,
 .get_freq =  th_get_freq,
@@ -168,6 +169,8 @@ const struct rig_caps thd7a_caps = {
 .get_ctcss_tone =  th_get_ctcss_tone,
 .set_mem =  th_set_mem,
 .get_mem =  th_get_mem,
+.set_channel =  th_set_channel,
+.get_channel =  th_get_channel,
 .set_trn =  th_set_trn,
 .get_trn =  th_get_trn,
 
@@ -176,6 +179,8 @@ const struct rig_caps thd7a_caps = {
 .get_parm =  th_get_parm,
 .get_info =  th_get_info,
 
+.get_dcd =  kenwood_get_dcd,
+
 .decode_event =  th_decode_event,
 };
 
