@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - TH-F7 description
- *  Copyright (c) 2001-2003 by Stephane Fillod
+ *  Copyright (c) 2001-2004 by Stephane Fillod
  *
- *	$Id: thf7.c,v 1.9 2003/10/01 19:31:58 fillods Exp $
+ *	$Id: thf7.c,v 1.12 2004/09/26 08:35:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -35,7 +35,7 @@
 
 #define THF7_FUNC_ALL (RIG_FUNC_TSQL|RIG_FUNC_AIP|RIG_FUNC_SQL)
 
-#define THF7_LEVEL_ALL (RIG_LEVEL_SQL|RIG_LEVEL_SQLSTAT|RIG_LEVEL_STRENGTH|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_MICGAIN)
+#define THF7_LEVEL_ALL (RIG_LEVEL_SQL|RIG_LEVEL_STRENGTH|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_MICGAIN)
 
 #define THF7_PARMS (RIG_PARM_BACKLIGHT)
 
@@ -83,7 +83,11 @@ const struct rig_caps thf7e_caps = {
 .has_set_level =  RIG_LEVEL_SET(THF7_LEVEL_ALL),
 .has_get_parm =  THF7_PARMS,
 .has_set_parm =  THF7_PARMS,    /* FIXME: parms */
-.level_gran =  {},                 /* FIXME: granularity */
+.level_gran = {
+        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 5 } },
+        [LVL_SQL] = { .min = { .i = 0 }, .max = { .i = 5 } },
+        [LVL_RFPOWER] = { .min = { .i = 3 }, .max = { .i = 0 } },
+},
 .parm_gran =  {},
 .ctcss_list =  kenwood38_ctcss_list,
 .dcs_list =  NULL,	/* FIXME */
@@ -133,10 +137,6 @@ const struct rig_caps thf7e_caps = {
 		RIG_FLT_END,
 	},
 .priv =  (void *)&thf7_priv_caps,
-.rig_init =  kenwood_init,
-.rig_cleanup =  kenwood_cleanup,
-.rig_open =  NULL,
-.rig_close =  NULL,
 
 .set_freq =  th_set_freq,
 .get_freq =  th_get_freq,
