@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - TS570 description
- *  Copyright (c) 2001,2002 by Stephane Fillod
+ *  Copyright (c) 2001-2004 by Stephane Fillod
  *
- *	$Id: ts570.c,v 1.18 2002/12/21 12:08:06 pa4tu Exp $
+ *	$Id: ts570.c,v 1.21 2004/09/26 08:35:04 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -24,6 +24,7 @@
 #include "config.h"
 #endif
 
+#include <stdio.h>
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
@@ -36,7 +37,7 @@
 
 #define TS570_FUNC_ALL (RIG_FUNC_FAGC|RIG_FUNC_TSQL|RIG_FUNC_TONE|RIG_FUNC_NB|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_NR|RIG_FUNC_LOCK|RIG_FUNC_BC)
 
-#define TS570_LEVEL_ALL (RIG_LEVEL_ATT|RIG_LEVEL_AGC|RIG_LEVEL_SQL|RIG_LEVEL_SQLSTAT|RIG_LEVEL_STRENGTH|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_RFPOWER|RIG_LEVEL_MICGAIN)
+#define TS570_LEVEL_ALL (RIG_LEVEL_ATT|RIG_LEVEL_AGC|RIG_LEVEL_SQL|RIG_LEVEL_STRENGTH|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_RFPOWER|RIG_LEVEL_MICGAIN)
 
 #define TS570_VFO (RIG_VFO_A|RIG_VFO_B)
 #define TS570_VFO_OP (RIG_OP_UP|RIG_OP_DOWN)
@@ -131,6 +132,8 @@ int ts570_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
       }
       *width = 50 * atoi(&buf[2]);
       break;
+    default:
+      return -RIG_EINVAL;
   }
 
   return RIG_OK;
@@ -169,7 +172,7 @@ int ts570_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     case RIG_MODE_CWR:
     case RIG_MODE_RTTY:
     case RIG_MODE_RTTYR:
-      buf_len = sprintf(buf, "FW%04d;", width);
+      buf_len = sprintf(buf, "FW%04d;", (int)width);
       ack_len = 0;
       retval = kenwood_transaction (rig, buf, buf_len, ackbuf, &ack_len);
       if (retval != RIG_OK) return retval;
@@ -183,6 +186,8 @@ int ts570_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
       retval = kenwood_transaction (rig, buf, buf_len, ackbuf, &ack_len);
       if (retval != RIG_OK) return retval;
       break;
+    default:
+      return -RIG_EINVAL;
   }
 
   return RIG_OK;
