@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - TS850 description
- *  Copyright (c) 2000-2003 by Stephane Fillod
+ *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: ts850.c,v 1.14 2004/02/14 16:50:53 f4dwv Exp $
+ *	$Id: ts850.c,v 1.18 2004/09/08 20:51:12 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -60,18 +60,18 @@ static const struct kenwood_priv_caps  ts850_priv_caps  = {
 };
 
 /* forward definitions */
-int ts850_set_rit(RIG * rig, vfo_t vfo, shortfreq_t rit);
-int ts850_set_xit(RIG * rig, vfo_t vfo, shortfreq_t rit);
-int ts850_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
-int ts850_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
-int ts850_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone);
-int ts850_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
-int ts850_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status);
-int ts850_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
-int ts850_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
-int ts850_get_mem(RIG *rig, vfo_t vfo, int *ch);
-int ts850_get_channel (RIG * rig, channel_t * chan);
-int ts850_set_channel (RIG * rig, const channel_t * chan);
+static int ts850_set_rit(RIG * rig, vfo_t vfo, shortfreq_t rit);
+static int ts850_set_xit(RIG * rig, vfo_t vfo, shortfreq_t rit);
+static int ts850_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
+static int ts850_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
+static int ts850_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone);
+static int ts850_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
+static int ts850_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status);
+static int ts850_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
+static int ts850_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
+static int ts850_get_mem(RIG *rig, vfo_t vfo, int *ch);
+static int ts850_get_channel (RIG * rig, channel_t * chan);
+static int ts850_set_channel (RIG * rig, const channel_t * chan);
 
 /*
  * ts850 rig capabilities.
@@ -82,7 +82,7 @@ const struct rig_caps ts850_caps = {
 .rig_model =  RIG_MODEL_TS850,
 .model_name = "TS-850",
 .mfg_name =  "Kenwood",
-.version =  "1.0",
+.version =  "1.1",
 .copyright =  "LGPL",
 .status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -94,10 +94,10 @@ const struct rig_caps ts850_caps = {
 .serial_data_bits =  8,
 .serial_stop_bits =  2,
 .serial_parity =  RIG_PARITY_NONE,
-.serial_handshake =  RIG_HANDSHAKE_NONE,
+.serial_handshake =  RIG_HANDSHAKE_HARDWARE,
 .write_delay =  0,
-.post_write_delay =  5,
-.timeout =  200,
+.post_write_delay =  500,
+.timeout =  1000,
 .retry =  3,
 
 .has_get_func =  TS850_FUNC_ALL,
@@ -505,7 +505,7 @@ int ts850_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 int ts850_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
                 unsigned char lvlbuf[50];
-                int lvl_len, retval;
+                int i, lvl_len, retval;
 
 		if(vfo!=RIG_VFO_CURR)
 			return -RIG_EINVAL;
@@ -518,11 +518,6 @@ int ts850_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
                         if (retval != RIG_OK)
                                 return retval;
 
-                        if (lvl_len != 7 || lvlbuf[1] != 'M') {
-                                rig_debug(RIG_DEBUG_ERR,"kenwood_get_level: wrong answer le n=%d\n", lvl_len);
-                                return -RIG_ERJCTED;
-			}
-
 			lvlbuf[6]='\0';
 			val->i=atoi(&lvlbuf[2]);
 			if(level==RIG_LEVEL_STRENGTH)
@@ -534,12 +529,16 @@ int ts850_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
                         if (retval != RIG_OK)
                                 return retval;
                 	lvl_len = 50;
-                        retval = kenwood_transaction (rig, "RM;", 4, lvlbuf, &lvl_len);
+                        retval = kenwood_transaction (rig, "RM;", 3, lvlbuf, &lvl_len);
                         if (retval != RIG_OK)
                                 return retval;
 
 			lvlbuf[7]='\0';
-			val->f=(float)atoi(&lvlbuf[3])/30.0;
+			i=atoi(&lvlbuf[3]);
+			if(i == 30) 
+				val->f = 150.0; /* infinity :-) */
+			else
+				val->f = 60.0/(30.0-(float)i)-1.0;
                         break;
                 case RIG_LEVEL_COMP:
                 	lvl_len = 0;
