@@ -1,8 +1,8 @@
 /*
  *  Hamlib Kenwood backend - TS870S description
- *  Copyright (c) 2000-2002 by Stephane Fillod
+ *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *	$Id: ts870s.c,v 1.35 2003/01/06 22:12:01 fillods Exp $
+ *	$Id: ts870s.c,v 1.38 2004/11/15 16:23:49 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -25,6 +25,8 @@
 #endif
 
 #include <stdlib.h>
+#include <stdio.h>
+
 #include <hamlib/rig.h>
 #include "kenwood.h"
 
@@ -55,6 +57,38 @@ static const struct kenwood_priv_caps  ts870s_priv_caps  = {
 		.cmdtrm =  EOM_KEN,
 };
 
+/* only the ts870s and ts2000 support get_vfo with the 'FR;' command 
+   NOTE: using byte 31 in 'IF' will also work. TODO: check other rigs */
+int ts870s_get_vfo(RIG *rig, vfo_t *vfo)
+{
+		unsigned char vfobuf[50];
+		int vfo_len, retval;
+
+
+		/* query RX VFO */
+		vfo_len = 50;
+		retval = kenwood_transaction (rig, "FR;", 3, vfobuf, &vfo_len);
+		if (retval != RIG_OK)
+			return retval;
+
+		if (vfo_len != 4 || vfobuf[1] != 'R') {
+			rig_debug(RIG_DEBUG_ERR,"%s: unexpected answer %s, "
+						"len=%d\n",__FUNCTION__,vfobuf, vfo_len);
+			return -RIG_ERJCTED;
+		}
+
+		/* TODO: replace 0,1,2,.. constants by defines */
+		switch (vfobuf[2]) {
+		case '0': *vfo = RIG_VFO_A; break;
+		case '1': *vfo = RIG_VFO_B; break;
+		case '2': *vfo = RIG_VFO_MEM; break;
+		default: 
+			rig_debug(RIG_DEBUG_ERR,"%s: unsupported VFO %c\n",
+							__FUNCTION__,vfobuf[2]);
+			return -RIG_EPROTO;
+		}
+		return RIG_OK;
+}
 
 int ts870s_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
@@ -69,8 +103,8 @@ int ts870s_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
   if (buf_len != 4 || buf[1] != 'D')
   {
-    rig_debug(RIG_DEBUG_ERR,"ts870s_get_mode: unexpected MD answer, len=%d\n",
-      buf_len);
+    rig_debug(RIG_DEBUG_ERR,"%s: unexpected MD answer, len=%d\n",
+      __FUNCTION__,buf_len);
     return -RIG_ERJCTED;
   }
 
@@ -86,8 +120,8 @@ int ts870s_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
     case MD_FSKR:	*mode = RIG_MODE_RTTYR; break;
     case MD_NONE:	*mode = RIG_MODE_NONE; break;
     default:
-      rig_debug(RIG_DEBUG_ERR,"ts870s_get_mode: "
-        "unsupported mode '%c'\n", buf[2]);
+      rig_debug(RIG_DEBUG_ERR,"%s: unsupported mode '%c'\n",
+		      __FUNCTION__,buf[2]);
       return -RIG_EINVAL;
   }
 
@@ -98,8 +132,8 @@ int ts870s_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
   if (buf_len != 7 || buf[1] != 'W')
   {
-    rig_debug(RIG_DEBUG_ERR,"ts870s_get_mode: unexpected FW answer, len=%d\n",
-      buf_len);
+    rig_debug(RIG_DEBUG_ERR,"%s: unexpected FW answer, len=%d\n",
+			__FUNCTION__,buf_len);
     return -RIG_ERJCTED;
   }
   
@@ -124,8 +158,8 @@ int ts870s_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     case RIG_MODE_RTTY:     kmode = MD_FSK; break;
     case RIG_MODE_RTTYR:    kmode = MD_FSKR; break;
     default:
-      rig_debug(RIG_DEBUG_ERR,"ts870s_set_mode: "
-	"unsupported mode %d\n", mode);
+      rig_debug(RIG_DEBUG_ERR,"%s: unsupported mode %d\n",
+		      __FUNCTION__,mode);
       return -RIG_EINVAL;
   }
 
@@ -158,7 +192,7 @@ const struct rig_caps ts870s_caps = {
 .rig_model =  RIG_MODEL_TS870S,
 .model_name = "TS-870S",
 .mfg_name =  "Kenwood",
-.version =  "0.3.2",
+.version =  "0.3.4",
 .copyright =  "LGPL",
 .status =  RIG_STATUS_BETA,
 .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -299,7 +333,7 @@ const struct rig_caps ts870s_caps = {
 .set_mode =  ts870s_set_mode,
 .get_mode =  ts870s_get_mode,
 .set_vfo =  kenwood_set_vfo,
-.get_vfo =  kenwood_get_vfo,
+.get_vfo =  ts870s_get_vfo,
 .set_ctcss_tone =  kenwood_set_ctcss_tone,
 .get_ctcss_tone =  kenwood_get_ctcss_tone,
 .get_ptt =  kenwood_get_ptt,
