@@ -1,8 +1,8 @@
 /*
  *  Hamlib Interface - generic file based io functions
- *  Copyright (c) 2000-2003 by Stephane Fillod and Frank Singleton
+ *  Copyright (c) 2000-2004 by Stephane Fillod and Frank Singleton
  *
- *	$Id: iofunc.c,v 1.7 2003/04/07 22:41:57 fillods Exp $
+ *	$Id: iofunc.c,v 1.13 2004/10/02 10:32:08 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -38,6 +38,12 @@
 #include "iofunc.h"
 #include "misc.h"
 
+#if defined(WIN32) && !defined(HAVE_TERMIOS_H)
+#include "win32termios.h"
+#define read win32_serial_read
+#define write win32_serial_write
+#define select win32_serial_select
+#endif
 
 /*
  * Write a block of count characters to file descriptor,
@@ -69,7 +75,7 @@
  * it could work very well also with any file handle, like a socket.
  */
 
-int write_block(port_t *p, const char *txbuffer, size_t count)
+int HAMLIB_API write_block(port_t *p, const char *txbuffer, size_t count)
 {
   int i;
 
@@ -79,10 +85,10 @@ int write_block(port_t *p, const char *txbuffer, size_t count)
 		  struct timeval tv;
 
 		  /* FIXME in Y2038 ... */
-		  gettimeofday(tv, NULL);
+		  gettimeofday(&tv, NULL);
 		  date_delay = p->post_write_delay*1000 - 
-				  		((tv.tv_sec - p->post_write_date->tv_sec)*1000000 +
-				  		 (tv.tv_usec - p->post_write_date->tv_usec));
+				  		((tv.tv_sec - p->post_write_date.tv_sec)*1000000 +
+				  		 (tv.tv_usec - p->post_write_date.tv_usec));
 		  if (date_delay > 0) {
 				/*
 				 * optional delay after last write 
@@ -110,14 +116,17 @@ int write_block(port_t *p, const char *txbuffer, size_t count)
 #ifdef WANT_NON_ACTIVE_POST_WRITE_DELAY
 #define POST_WRITE_DELAY_TRSHLD 10
 
-	if (p->post_write_delay > POST_WRITE_DELAY_TRSHLD)
-		gettimeofday(p->post_write_date, NULL);
+	if (p->post_write_delay > POST_WRITE_DELAY_TRSHLD) {
+		struct timeval tv;
+		gettimeofday(&tv, NULL);
+		p->post_write_date.tv_sec = tv.tv_sec;
+		p->post_write_date.tv_usec = tv.tv_usec;
+	}
 	else
-#else
+#endif
     usleep(p->post_write_delay*1000); /* optional delay after last write */
 				   /* otherwise some yaesu rigs get confused */
 				   /* with sequential fast writes*/
-#endif
   }
   rig_debug(RIG_DEBUG_TRACE,"TX %d bytes\n",count);
   dump_hex(txbuffer,count);
@@ -138,7 +147,7 @@ int write_block(port_t *p, const char *txbuffer, size_t count)
  * it could work very well also with any file handle, like a socket.
  */
 
-int read_block(port_t *p, char *rxbuffer, size_t count)
+int HAMLIB_API read_block(port_t *p, char *rxbuffer, size_t count)
 {  
   fd_set rfds;
   struct timeval tv, tv_timeout;
@@ -190,77 +199,6 @@ int read_block(port_t *p, char *rxbuffer, size_t count)
   return total_count;			/* return bytes count read */
 }
 
-int fread_block(port_t *p, char *rxbuffer, size_t count)
-{  
-  fd_set rfds;
-  struct timeval tv, tv_timeout;
-  int rd_count, total_count = 0;
-  int retval;
-  int fd;
-
-  fd = fileno(p->stream);
-
-  FD_ZERO(&rfds);
-  FD_SET(fd, &rfds);
-
-  /*
-   * Wait up to timeout ms.
-   */
-  tv_timeout.tv_sec = p->timeout/1000;
-  tv_timeout.tv_usec = (p->timeout%1000)*1000;
-
-
-	/*
-	 * grab bytes from the rig
-	 * The file descriptor must have been set up non blocking.
-	 */
-  	rd_count = fread(rxbuffer, 1, count, p->stream);
-	if (rd_count < 0) {
-			rig_debug(RIG_DEBUG_ERR, "read_block: read failed - %s\n",
-								strerror(errno));
-			return -RIG_EIO;
-	}
-	total_count += rd_count;
-	count -= rd_count;
-
-  while (count > 0) {
-		tv = tv_timeout;	/* select may have updated it */
-
-		retval = select(fd+1, &rfds, NULL, NULL, &tv);
-		if (retval == 0) {
-			dump_hex(rxbuffer, total_count);
-#if 0
-			rig_debug(RIG_DEBUG_WARN, "fread_block: timedout after %d chars\n",
-							total_count);
-#endif
-				return -RIG_ETIMEOUT;
-		}
-		if (retval < 0) {
-			dump_hex(rxbuffer, total_count);
-			rig_debug(RIG_DEBUG_ERR,"fread_block: select error after %d chars: "
-							"%s\n", total_count, strerror(errno));
-				return -RIG_EIO;
-		}
-
-		/*
-		 * grab bytes from the rig
-		 * The file descriptor must have been set up non blocking.
-		 */
-  		rd_count = fread(rxbuffer+total_count, 1, count, p->stream);
-		if (rd_count < 0) {
-				dump_hex(rxbuffer, total_count);
-				rig_debug(RIG_DEBUG_ERR, "read_block: read failed - %s\n",
-									strerror(errno));
-				return -RIG_EIO;
-		}
-		total_count += rd_count;
-		count -= rd_count;
-  }
-
-  rig_debug(RIG_DEBUG_TRACE,"RX %d bytes\n",total_count);
-  dump_hex(rxbuffer, total_count);
-  return total_count;			/* return bytes count read */
-}
 
 /*
  * Read a string from "fd" and put result into
@@ -277,7 +215,7 @@ int fread_block(port_t *p, char *rxbuffer, size_t count)
  *
  * Assumes rxbuffer!=NULL
  */
-int read_string(port_t *p, char *rxbuffer, size_t rxmax, const char *stopset,
+int HAMLIB_API read_string(port_t *p, char *rxbuffer, size_t rxmax, const char *stopset,
 				int stopset_len)
 {
   fd_set rfds;
