@@ -1,8 +1,8 @@
 /*
  *  Hamlib Interface - provides registering for dynamically loadable backends.
- *  Copyright (c) 2000,2001 by Stephane Fillod and Frank Singleton
+ *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *		$Id: register.c,v 1.10 2001/09/19 21:58:33 f4cfe Exp $
+ *	$Id: register.c,v 1.21 2004/10/02 10:32:08 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -34,7 +34,6 @@
 /* This is libtool's dl wrapper */
 #include <ltdl.h>
 
-#define HAMLIB_DLL
 #include <hamlib/rig.h>
 
 
@@ -54,7 +53,7 @@
 static struct {
 	int be_num;
 	const char *be_name;
-    rig_model_t (*be_probe)(port_t *);
+	rig_model_t (* be_probe_all)(port_t*, rig_probe_func_t, rig_ptr_t);
 } rig_backend_list[RIG_BACKEND_MAX] = RIG_BACKEND_LIST;
 
 
@@ -83,7 +82,7 @@ static int rig_lookup_backend(rig_model_t rig_model);
 /*
  * Basically, this is a hash insert function that doesn't check for dup!
  */
-int rig_register(const struct rig_caps *caps)
+int HAMLIB_API rig_register(const struct rig_caps *caps)
 {
 		int hval;
 		struct rig_list *p;
@@ -116,7 +115,7 @@ int rig_register(const struct rig_caps *caps)
  * ie. rig_hash_table lookup
  */
 
-const struct rig_caps *rig_get_caps(rig_model_t rig_model)
+const struct rig_caps * HAMLIB_API rig_get_caps(rig_model_t rig_model)
 {
 		struct rig_list *p;
 
@@ -150,7 +149,7 @@ static int rig_lookup_backend(rig_model_t rig_model)
  * and if not loaded already, load it!
  * This permits seamless operation in rig_init.
  */
-int rig_check_backend(rig_model_t rig_model)
+int HAMLIB_API rig_check_backend(rig_model_t rig_model)
 {
 		const struct rig_caps *caps;
 		int be_idx;
@@ -181,7 +180,7 @@ int rig_check_backend(rig_model_t rig_model)
 
 
 
-int rig_unregister(rig_model_t rig_model)
+int HAMLIB_API rig_unregister(rig_model_t rig_model)
 {
 		int hval;
 		struct rig_list *p,*q;
@@ -206,7 +205,7 @@ int rig_unregister(rig_model_t rig_model)
  * rig_list_foreach
  * executes cfunc on all the elements stored in the rig hash list
  */
-int rig_list_foreach(int (*cfunc)(const struct rig_caps*, rig_ptr_t),rig_ptr_t data)
+int HAMLIB_API rig_list_foreach(int (*cfunc)(const struct rig_caps*, rig_ptr_t),rig_ptr_t data)
 {
 	struct rig_list *p;
 	int i;
@@ -222,25 +221,48 @@ int rig_list_foreach(int (*cfunc)(const struct rig_caps*, rig_ptr_t),rig_ptr_t d
 	return RIG_OK;
 }
 
+static int dummy_rig_probe(const port_t *p, rig_model_t model, rig_ptr_t data)
+{
+	rig_debug(RIG_DEBUG_TRACE, "Found rig, model %d\n", model);
+	return RIG_OK;
+}
+
 /*
- * rig_probe_all
+ * rig_probe_first
  * called straight by rig_probe
  */
-rig_model_t rig_probe_all(port_t *p)
+rig_model_t rig_probe_first(port_t *p)
 {
 	int i;
-	rig_model_t rig_model;
+	rig_model_t model;
 
 	for (i=0; i<RIG_BACKEND_MAX && rig_backend_list[i].be_name; i++) {
-			if (rig_backend_list[i].be_probe) {
-					rig_model = (*rig_backend_list[i].be_probe)(p);
-					if (rig_model != RIG_MODEL_NONE)
-							return rig_model;
-			}
+		if (rig_backend_list[i].be_probe_all) {
+			model = (*rig_backend_list[i].be_probe_all)(p, dummy_rig_probe, (rig_ptr_t)NULL);
+			/* stop at first one found */
+			if (model != RIG_MODEL_NONE)
+				return model;
+		}
 	}
 	return RIG_MODEL_NONE;
 }
 
+/*
+ * rig_probe_all_backends
+ * called straight by rig_probe_all
+ */
+int rig_probe_all_backends(port_t *p, rig_probe_func_t cfunc, rig_ptr_t data)
+{
+	int i;
+
+	for (i=0; i<RIG_BACKEND_MAX && rig_backend_list[i].be_name; i++) {
+		if (rig_backend_list[i].be_probe_all) {
+			(*rig_backend_list[i].be_probe_all)(p, cfunc, data);
+		}
+	}
+	return RIG_OK;
+}
+
 
 int rig_load_all_backends()
 {
@@ -258,57 +280,63 @@ int rig_load_all_backends()
  * rig_load_backend
  * Dynamically load a rig backend through dlopen mechanism
  */
-int rig_load_backend(const char *be_name)
+int HAMLIB_API rig_load_backend(const char *be_name)
 {
-		/*
-		 * determine PREFIX and POSTFIX values from configure script
-		 */
-#ifdef __CYGWIN__
-# define PREFIX "cyghamlib-"
-# define POSTFIX ".dll"
-#else
-# define PREFIX "libhamlib-"
-# define POSTFIX ".la"
-#endif
+# define PREFIX "hamlib-"
 
 	lt_dlhandle be_handle;
     int (*be_init)(rig_ptr_t);
 	int status;
 	char libname[PATH_MAX];
-	char initfname[MAXFUNCNAMELEN]  = "init_";
-	char probefname[MAXFUNCNAMELEN] = "probe_";
+	char initfname[MAXFUNCNAMELEN];
+	char probefname[MAXFUNCNAMELEN];
 	int i;
 
 	/*
 	 * lt_dlinit may be called several times
+	 *
+	 * FIXME: make static build seamless
 	 */
-#ifdef	HAVE_PRELOADED_SYMBOLS
+#if 0
 	LTDL_SET_PRELOADED_SYMBOLS();
 #endif
+
 	status = lt_dlinit();
 	if (status) {
     		rig_debug(RIG_DEBUG_ERR, "rig_backend_load: lt_dlinit for %s "
-							"failed: %d\n", be_name, status);
+							"failed: %s\n", be_name, lt_dlerror());
     		return -RIG_EINTERNAL;
 	}
 
+	lt_dladdsearchdir(HAMLIB_MODULE_DIR);
+
 	rig_debug(RIG_DEBUG_VERBOSE, "rig: loading backend %s\n",be_name);
 
 	/*
 	 * add hamlib directory here
 	 */
-	snprintf (libname, sizeof (libname), PREFIX"%s"POSTFIX, be_name);
+	snprintf (libname, sizeof (libname), PREFIX"%s", be_name);
 
-	be_handle = lt_dlopen (libname);
+	be_handle = lt_dlopenext (libname);
+
+	/*
+	 * external module not found? try dlopenself for backends 
+	 * compiled in static
+	 */
+	if (!be_handle) {
+		rig_debug(RIG_DEBUG_VERBOSE, "rig:  lt_dlopen(\"%s\") failed (%s), "
+						"trying static symbols...\n",
+						libname, lt_dlerror());
+		be_handle = lt_dlopen (NULL);
+	}
 
 	if (!be_handle) {
-		rig_debug(RIG_DEBUG_ERR, "rig: lt_dlopen(\"%s\") failed (%s)\n",
+		rig_debug(RIG_DEBUG_ERR, "rig:  lt_dlopen(\"%s\") failed (%s)\n",
 						libname, lt_dlerror());
 		return -RIG_EINVAL;
     }
 
-
-    strncat(initfname, be_name, MAXFUNCNAMELEN);
+    snprintf(initfname, MAXFUNCNAMELEN, "initrigs%d_%s", ABI_VERSION, be_name);
     be_init = (int (*)(rig_ptr_t)) lt_dlsym (be_handle, initfname);
 	if (!be_init) {
 			rig_debug(RIG_DEBUG_ERR, "rig: dlsym(%s) failed (%s)\n",
@@ -325,8 +353,9 @@ int rig_load_backend(const char *be_name)
 	 */
 	for (i=0; i<RIG_BACKEND_MAX && rig_backend_list[i].be_name; i++) {
 		if (!strncmp(be_name, rig_backend_list[i].be_name, 64)) {
-    			strncat(probefname, be_name, MAXFUNCNAMELEN);
-    			rig_backend_list[i].be_probe = (rig_model_t (*)(port_t *))
+    			snprintf(probefname, MAXFUNCNAMELEN, "probeallrigs%d_%s", ABI_VERSION, be_name);
+    			rig_backend_list[i].be_probe_all = 
+				(rig_model_t (*)(port_t*, rig_probe_func_t, rig_ptr_t))
 						lt_dlsym (be_handle, probefname);
 				break;
 		}
