@@ -1,8 +1,8 @@
 /*
  *  Hamlib Interface - main file
- *  Copyright (c) 2000-2003 by Stephane Fillod and Frank Singleton
+ *  Copyright (c) 2000-2004 by Stephane Fillod and Frank Singleton
  *
- *	$Id: rig.c,v 1.71 2003/04/27 22:15:06 fillods Exp $
+ *	$Id: rig.c,v 1.83 2004/10/02 20:37:24 fillods Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -26,7 +26,7 @@
  * \brief Ham Radio Control Libraries interface
  * \author Stephane Fillod
  * \author Frank Singleton
- * \date 2000-2003
+ * \date 2000-2004
  *
  * Hamlib interface is a frontend implementing wrapper functions.
  */
@@ -56,8 +56,9 @@
 #include <fcntl.h>
 
 
-#include <hamlib/rig.h>
-#include <serial.h>
+#include "hamlib/rig.h"
+#include "serial.h"
+#include "parallel.h"
 #include "event.h"
 
 /**
@@ -69,14 +70,24 @@ const char hamlib_version[] = "Hamlib version " PACKAGE_VERSION;
  * \brief Hamlib copyright notice
  */
 const char hamlib_copyright[] = 
-  "Copyright (C) 2000, 2001, 2002 Stephane Fillod and Frank Singleton\n"
+  "Copyright (C) 2000-2004 Stephane Fillod and Frank Singleton\n"
   "This is free software; see the source for copying conditions.  There is NO\n"
   "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.";
 
 
 #ifndef DOC_HIDDEN
 
+#if defined(WIN32) && !defined(__CYGWIN__)
+#define DEFAULT_SERIAL_PORT "\\\\.\\COM1"
+#else
 #define DEFAULT_SERIAL_PORT "/dev/ttyS0"
+#endif
+
+#if defined(WIN32)
+#define DEFAULT_PARALLEL_PORT "\\\\.\\$VDMLPT1"
+#else
+#define DEFAULT_PARALLEL_PORT "/dev/parport0"
+#endif
 
 #define CHECK_RIG_ARG(r) (!(r) || !(r)->caps || !(r)->state.comm_state)
 
@@ -110,6 +121,9 @@ static const char *rigerror_table[] = {
 		"Target VFO unaccessible",
 		"Communication bus error",
 		"Communication bus collision",
+		"NULL RIG handle or invalid pointer parameter",
+		"Invalid VFO",
+		"Argument out of domain of func",
 		NULL,
 };
 
@@ -193,7 +207,7 @@ int foreach_opened_rig(int (*cfunc)(RIG *, rig_ptr_t), rig_ptr_t data)
  *
  * \todo support gettext/localization
  */
-const char *rigerror(int errnum)
+const char * HAMLIB_API rigerror(int errnum)
 {
 		errnum = abs(errnum);
 		if (errnum > ERROR_TBL_SZ)
@@ -214,7 +228,7 @@ const char *rigerror(int errnum)
  * \sa rig_cleanup(), rig_open()
  */
 
-RIG *rig_init(rig_model_t rig_model)
+RIG * HAMLIB_API rig_init(rig_model_t rig_model)
 {
 		RIG *rig;
 		const struct rig_caps *caps;
@@ -253,15 +267,27 @@ RIG *rig_init(rig_model_t rig_model)
 
 		rs->comm_state = 0;
 		rs->rigport.type.rig = caps->port_type; /* default from caps */
+
+		switch (caps->port_type) {
+		case RIG_PORT_SERIAL:
 		strncpy(rs->rigport.pathname, DEFAULT_SERIAL_PORT, FILPATHLEN);
 		rs->rigport.parm.serial.rate = caps->serial_rate_max;	/* fastest ! */
 		rs->rigport.parm.serial.data_bits = caps->serial_data_bits;
 		rs->rigport.parm.serial.stop_bits = caps->serial_stop_bits;
 		rs->rigport.parm.serial.parity = caps->serial_parity;
 		rs->rigport.parm.serial.handshake = caps->serial_handshake;
+		break;
+
+		case RIG_PORT_PARALLEL:
+		strncpy(rs->rigport.pathname, DEFAULT_PARALLEL_PORT, FILPATHLEN);
+		break;
+
+		default:
+		strncpy(rs->rigport.pathname, "", FILPATHLEN);
+		}
+
 		rs->rigport.write_delay = caps->write_delay;
 		rs->rigport.post_write_delay = caps->post_write_delay;
-
 		rs->rigport.timeout = caps->timeout;
 		rs->rigport.retry = caps->retry;
 		rs->pttport.type.ptt = caps->ptt_type;
@@ -269,7 +295,8 @@ RIG *rig_init(rig_model_t rig_model)
 
 		rs->vfo_comp = 0.0;	/* override it with preferences */
 		rs->current_vfo = RIG_VFO_CURR;	/* we don't know yet! */
-		rs->transceive = caps->transceive;
+		rs->transceive = RIG_TRN_OFF;
+		rs->poll_interval = 500;
 		/* should it be a parameter to rig_init ? --SF */
 		rs->itu_region = RIG_ITU_REGION2;
 
@@ -304,6 +331,9 @@ RIG *rig_init(rig_model_t rig_model)
 						sizeof(struct tuning_step_list)*TSLSTSIZ);
 		memcpy(rs->filters, caps->filters, 
 						sizeof(struct filter_list)*FLTLSTSIZ);
+		memcpy(&rs->str_cal, &caps->str_cal, 
+						sizeof(cal_table_t));
+
 		memcpy(rs->chan_list, caps->chan_list, sizeof(chan_t)*CHANLSTSIZ);
 
 		rs->has_get_func = caps->has_get_func;
@@ -313,6 +343,14 @@ RIG *rig_init(rig_model_t rig_model)
 		rs->has_get_parm = caps->has_get_parm;
 		rs->has_set_parm = caps->has_set_parm;
 
+		/* emulation by frontend */
+		if ((caps->has_get_level & RIG_LEVEL_STRENGTH) == 0 &&
+			(caps->has_get_level & RIG_LEVEL_RAWSTR) == RIG_LEVEL_RAWSTR)
+			rs->has_get_level |= RIG_LEVEL_STRENGTH;
+
+		memcpy(rs->level_gran, caps->level_gran, sizeof(gran_t)*RIG_SETTING_MAX);
+		memcpy(rs->parm_gran, caps->parm_gran, sizeof(gran_t)*RIG_SETTING_MAX);
+
 		rs->max_rit = caps->max_rit;
 		rs->max_xit = caps->max_xit;
 		rs->max_ifshift = caps->max_ifshift;
@@ -355,7 +393,7 @@ RIG *rig_init(rig_model_t rig_model)
  * \sa rig_init(), rig_close()
  */
 
-int rig_open(RIG *rig)
+int HAMLIB_API rig_open(RIG *rig)
 {
 		const struct rig_caps *caps;
 		struct rig_state *rs;
@@ -377,7 +415,7 @@ int rig_open(RIG *rig)
 		switch(rs->rigport.type.rig) {
 		case RIG_PORT_SERIAL:
 				status = serial_open(&rs->rigport);
-				if (status != 0)
+				if (status < 0)
 						return status;
 				if (rs->rigport.parm.serial.rts_state != RIG_SIGNAL_UNSET &&
 						rs->rigport.type.ptt != RIG_PTT_SERIAL_RTS &&
@@ -396,6 +434,12 @@ int rig_open(RIG *rig)
 					return status;
 				break;
 
+		case RIG_PORT_PARALLEL:
+				status = par_open(&rs->rigport);
+				if (status < 0)
+					return status;
+				break;
+
 		case RIG_PORT_DEVICE:
 				status = open(rs->rigport.pathname, O_RDWR, 0);
 				if (status < 0)
@@ -445,6 +489,7 @@ int rig_open(RIG *rig)
 				break;
 		case RIG_DCD_SERIAL_DSR:
 		case RIG_DCD_SERIAL_CTS:
+		case RIG_DCD_SERIAL_CAR:
 				rs->dcdport.fd = ser_open(&rs->dcdport);
 				if (rs->dcdport.fd < 0)
 					rig_debug(RIG_DEBUG_ERR, "Cannot open DCD device \"%s\"\n",
@@ -509,88 +554,91 @@ int rig_open(RIG *rig)
  * \sa rig_cleanup(), rig_open()
  */
 
-int rig_close(RIG *rig)
+int HAMLIB_API rig_close(RIG *rig)
 {
-		const struct rig_caps *caps;
-		struct rig_state *rs;
+	const struct rig_caps *caps;
+	struct rig_state *rs;
 
-		rig_debug(RIG_DEBUG_VERBOSE,"rig:rig_close called \n");
+	rig_debug(RIG_DEBUG_VERBOSE,"rig:rig_close called \n");
 
-		if (!rig || !rig->caps)
-				return -RIG_EINVAL;
+	if (!rig || !rig->caps)
+		return -RIG_EINVAL;
 
-		caps = rig->caps;
-		rs = &rig->state;
+	caps = rig->caps;
+	rs = &rig->state;
 
-		if (!rs->comm_state)
-				return -RIG_EINVAL;
+	if (!rs->comm_state)
+		return -RIG_EINVAL;
 
-		if (rs->transceive) {
-				/*
-				 * TODO: check error codes et al.
-				 */
-				remove_trn_rig(rig);
-		}
+	if (rs->transceive != RIG_TRN_OFF) {
+		remove_trn_rig(rig);
+	}
 
-		/*
-		 * Let the backend say 73s to the rig.
-		 * and ignore the return code.
-		 */
-		if (caps->rig_close)
-				caps->rig_close(rig);
+	/*
+	 * Let the backend say 73s to the rig.
+	 * and ignore the return code.
+	 */
+	if (caps->rig_close)
+		caps->rig_close(rig);
 
-		/* 
-		 * FIXME: what happens if PTT and rig ports are the same?
-		 * 			(eg. ptt_type = RIG_PTT_SERIAL)
-		 */
-		switch(rs->pttport.type.ptt) {
-		case RIG_PTT_NONE:
-		case RIG_PTT_RIG:
-				break;
-		case RIG_PTT_SERIAL_RTS:
-		case RIG_PTT_SERIAL_DTR:
-				ser_close(&rs->pttport);
-				break;
-		case RIG_PTT_PARALLEL:
-				par_close(&rs->pttport);
-				break;
+	/* 
+	 * FIXME: what happens if PTT and rig ports are the same?
+	 * 			(eg. ptt_type = RIG_PTT_SERIAL)
+	 */
+	switch(rs->pttport.type.ptt) {
+	case RIG_PTT_NONE:
+	case RIG_PTT_RIG:
+			break;
+	case RIG_PTT_SERIAL_RTS:
+	case RIG_PTT_SERIAL_DTR:
+			ser_close(&rs->pttport);
+			break;
+	case RIG_PTT_PARALLEL:
+			par_close(&rs->pttport);
+			break;
+	default:
+			rig_debug(RIG_DEBUG_ERR, "Unsupported PTT type %d\n",
+							rs->pttport.type.ptt);
+	}
+
+	switch(rs->dcdport.type.dcd) {
+	case RIG_DCD_NONE:
+	case RIG_DCD_RIG:
+			break;
+	case RIG_DCD_SERIAL_DSR:
+	case RIG_DCD_SERIAL_CTS:
+	case RIG_DCD_SERIAL_CAR:
+			ser_close(&rs->dcdport);
+			break;
+	case RIG_DCD_PARALLEL:
+			par_close(&rs->dcdport);
+			break;
+	default:
+			rig_debug(RIG_DEBUG_ERR, "Unsupported DCD type %d\n",
+							rs->dcdport.type.dcd);
+	}
+
+	rs->dcdport.fd = rs->pttport.fd = -1;
+
+	if (rs->rigport.fd != -1) {
+		switch(rs->rigport.type.rig) {
+		case RIG_PORT_SERIAL:
+			ser_close(&rs->rigport);
+			break;
+		case RIG_PORT_PARALLEL:
+			par_close(&rs->rigport);
+			break;
 		default:
-				rig_debug(RIG_DEBUG_ERR, "Unsupported PTT type %d\n",
-								rs->pttport.type.ptt);
+			close(rs->rigport.fd);
 		}
+		rs->rigport.fd = -1;
+	}
 
-		switch(rs->dcdport.type.dcd) {
-		case RIG_DCD_NONE:
-		case RIG_DCD_RIG:
-				break;
-		case RIG_DCD_SERIAL_DSR:
-		case RIG_DCD_SERIAL_CTS:
-				ser_close(&rs->dcdport);
-				break;
-		case RIG_DCD_PARALLEL:
-				par_close(&rs->dcdport);
-				break;
-		default:
-				rig_debug(RIG_DEBUG_ERR, "Unsupported DCD type %d\n",
-								rs->dcdport.type.dcd);
-		}
+	remove_opened_rig(rig);
 
-		rs->dcdport.fd = rs->pttport.fd = -1;
+	rs->comm_state = 0;
 
-		if (rs->rigport.fd != -1) {
-				if (!rs->rigport.stream)
-						fclose(rs->rigport.stream); /* this closes also fd */
-				else
-					close(rs->rigport.fd);
-				rs->rigport.fd = -1;
-				rs->rigport.stream = NULL;
-		}
-
-		remove_opened_rig(rig);
-
-		rs->comm_state = 0;
-
-		return RIG_OK;
+	return RIG_OK;
 }
 
 /**
@@ -607,7 +655,7 @@ int rig_close(RIG *rig)
  * \sa rig_init(), rig_close()
  */
 
-int rig_cleanup(RIG *rig)
+int HAMLIB_API rig_cleanup(RIG *rig)
 {
 		rig_debug(RIG_DEBUG_VERBOSE,"rig:rig_cleanup called \n");
 
@@ -647,37 +695,42 @@ int rig_cleanup(RIG *rig)
  * \sa rig_get_freq()
  */
 
-int rig_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
+int HAMLIB_API rig_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-		const struct rig_caps *caps;
-		int retcode;
-		vfo_t curr_vfo;
+	const struct rig_caps *caps;
+	int retcode;
+	vfo_t curr_vfo;
 
-		if (CHECK_RIG_ARG(rig))
-			return -RIG_EINVAL;
+	if (CHECK_RIG_ARG(rig))
+		return -RIG_EINVAL;
 
-		caps = rig->caps;
+	caps = rig->caps;
 
-		if (rig->state.vfo_comp != 0.0)
-				freq += (freq_t)((double)rig->state.vfo_comp * freq);
+	if (rig->state.vfo_comp != 0.0)
+		freq += (freq_t)((double)rig->state.vfo_comp * freq);
 
-		if (caps->set_freq == NULL)
-			return -RIG_ENAVAIL;
-
-		if ((caps->targetable_vfo&RIG_TARGETABLE_FREQ) || 
-						vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo)
-			return caps->set_freq(rig, vfo, freq);
+	if (caps->set_freq == NULL)
+		return -RIG_ENAVAIL;
 
+	if ((caps->targetable_vfo&RIG_TARGETABLE_FREQ) || 
+			vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo) {
+		retcode = caps->set_freq(rig, vfo, freq);
+	} else {
 		if (!caps->set_vfo)
 			return -RIG_ENTARGET;
 		curr_vfo = rig->state.current_vfo;
 		retcode = caps->set_vfo(rig, vfo);
 		if (retcode != RIG_OK)
-				return retcode;
+			return retcode;
 
 		retcode = caps->set_freq(rig, vfo, freq);
 		caps->set_vfo(rig, curr_vfo);
-		return retcode;
+	}
+	if (retcode == RIG_OK &&
+			(vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo))
+		rig->state.current_freq = freq;
+
+	return retcode;
 }
 
 /**
@@ -697,37 +750,42 @@ int rig_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
  * \sa rig_set_freq()
  */
 
-int rig_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
+int HAMLIB_API rig_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-		const struct rig_caps *caps;
-		int retcode;
-		vfo_t curr_vfo;
+	const struct rig_caps *caps;
+	int retcode;
+	vfo_t curr_vfo;
 
-		if (CHECK_RIG_ARG(rig) || !freq)
-			return -RIG_EINVAL;
+	if (CHECK_RIG_ARG(rig) || !freq)
+		return -RIG_EINVAL;
 
-		caps = rig->caps;
+	caps = rig->caps;
 
-		if (caps->get_freq == NULL)
+	if (caps->get_freq == NULL)
+		return -RIG_ENAVAIL;
+
+	if ((caps->targetable_vfo&RIG_TARGETABLE_FREQ) || 
+			vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo) {
+		retcode = caps->get_freq(rig, vfo, freq);
+	} else {
+		if (!caps->set_vfo)
 			return -RIG_ENAVAIL;
+		curr_vfo = rig->state.current_vfo;
+		retcode = caps->set_vfo(rig, vfo);
+		if (retcode != RIG_OK)
+			return retcode;
+		retcode = caps->get_freq(rig, vfo, freq);
+		caps->set_vfo(rig, curr_vfo);
+	}
+	/* VFO compensation */
+	if (rig->state.vfo_comp != 0.0)
+		*freq += (freq_t)(rig->state.vfo_comp * (*freq));
 
-		if ((caps->targetable_vfo&RIG_TARGETABLE_FREQ) || 
-				vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo) {
-			retcode = caps->get_freq(rig, vfo, freq);
-		} else {
-			if (!caps->set_vfo)
-				return -RIG_ENAVAIL;
-			curr_vfo = rig->state.current_vfo;
-			retcode = caps->set_vfo(rig, vfo);
-			if (retcode != RIG_OK)
-					return retcode;
-			retcode = caps->get_freq(rig, vfo, freq);
-			caps->set_vfo(rig, curr_vfo);
-		}
-		/* VFO compensation */
-		if (rig->state.vfo_comp != 0.0)
-			*freq += (freq_t)(rig->state.vfo_comp * (*freq));
-		return retcode;
+	if (retcode == RIG_OK &&
+			(vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo))
+		rig->state.current_freq = *freq;
+
+	return retcode;
 }
 
 
@@ -748,34 +806,43 @@ int rig_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
  * \sa rig_get_mode()
  */
 
-int rig_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
+int HAMLIB_API rig_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
-		const struct rig_caps *caps;
-		int retcode;
-		vfo_t curr_vfo;
+	const struct rig_caps *caps;
+	int retcode;
+	vfo_t curr_vfo;
 
-		if (CHECK_RIG_ARG(rig))
-			return -RIG_EINVAL;
+	if (CHECK_RIG_ARG(rig))
+		return -RIG_EINVAL;
 
-		caps = rig->caps;
+	caps = rig->caps;
 
-		if (caps->set_mode == NULL)
-			return -RIG_ENAVAIL;
+	if (caps->set_mode == NULL)
+		return -RIG_ENAVAIL;
 
-		if ((caps->targetable_vfo&RIG_TARGETABLE_ALL) ||
-				vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo)
-			return caps->set_mode(rig, vfo, mode, width);
+	if ((caps->targetable_vfo&RIG_TARGETABLE_ALL) ||
+			vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo) {
+		retcode = caps->set_mode(rig, vfo, mode, width);
+	} else {
 
 		if (!caps->set_vfo)
 			return -RIG_ENTARGET;
 		curr_vfo = rig->state.current_vfo;
 		retcode = caps->set_vfo(rig, vfo);
 		if (retcode != RIG_OK)
-				return retcode;
+			return retcode;
 
 		retcode = caps->set_mode(rig, vfo, mode, width);
 		caps->set_vfo(rig, curr_vfo);
-		return retcode;
+	}
+
+	if (retcode == RIG_OK &&
+			(vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo)) {
+		rig->state.current_mode = mode;
+		rig->state.current_width = width;
+	}
+
+	return retcode;
 }
 
 /**
@@ -798,34 +865,43 @@ int rig_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
  * \sa rig_set_mode()
  */
 
-int rig_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
+int HAMLIB_API rig_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-		const struct rig_caps *caps;
-		int retcode;
-		vfo_t curr_vfo;
+	const struct rig_caps *caps;
+	int retcode;
+	vfo_t curr_vfo;
 
-		if (CHECK_RIG_ARG(rig) || !mode || !width)
-			return -RIG_EINVAL;
+	if (CHECK_RIG_ARG(rig) || !mode || !width)
+		return -RIG_EINVAL;
 
-		caps = rig->caps;
+	caps = rig->caps;
 
-		if (caps->get_mode == NULL)
-			return -RIG_ENAVAIL;
+	if (caps->get_mode == NULL)
+		return -RIG_ENAVAIL;
 
-		if ((caps->targetable_vfo&RIG_TARGETABLE_ALL) || 
-						vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo)
-			return caps->get_mode(rig, vfo, mode, width);
+	if ((caps->targetable_vfo&RIG_TARGETABLE_ALL) || 
+			vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo) {
+		retcode = caps->get_mode(rig, vfo, mode, width);
+	} else {
 
 		if (!caps->set_vfo)
 			return -RIG_ENTARGET;
 		curr_vfo = rig->state.current_vfo;
 		retcode = caps->set_vfo(rig, vfo);
 		if (retcode != RIG_OK)
-				return retcode;
+			return retcode;
 
 		retcode = caps->get_mode(rig, vfo, mode, width);
 		caps->set_vfo(rig, curr_vfo);
-		return retcode;
+	}
+
+	if (retcode == RIG_OK &&
+			(vfo == RIG_VFO_CURR || vfo == rig->state.current_vfo)) {
+		rig->state.current_mode = *mode;
+		rig->state.current_width = *width;
+	}
+
+	return retcode;
 }
 
 /**
@@ -841,7 +917,7 @@ int rig_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
  * \sa rig_passband_narrow(), rig_passband_wide()
  */
 
-pbwidth_t rig_passband_normal(RIG *rig, rmode_t mode)
+pbwidth_t HAMLIB_API rig_passband_normal(RIG *rig, rmode_t mode)
 {
 		const struct rig_state *rs;
 		int i;
@@ -875,7 +951,7 @@ pbwidth_t rig_passband_normal(RIG *rig, rmode_t mode)
  * \sa rig_passband_normal(), rig_passband_wide()
  */
 
-pbwidth_t rig_passband_narrow(RIG *rig, rmode_t mode)
+pbwidth_t HAMLIB_API rig_passband_narrow(RIG *rig, rmode_t mode)
 {
 		const struct rig_state *rs;
 		pbwidth_t normal;
@@ -917,7 +993,7 @@ pbwidth_t rig_passband_narrow(RIG *rig, rmode_t mode)
  * \sa rig_passband_narrow(), rig_passband_normal()
  */
 
-pbwidth_t rig_passband_wide(RIG *rig, rmode_t mode)
+pbwidth_t HAMLIB_API rig_passband_wide(RIG *rig, rmode_t mode)
 {
 		const struct rig_state *rs;
 		pbwidth_t normal;
@@ -960,7 +1036,7 @@ pbwidth_t rig_passband_wide(RIG *rig, rmode_t mode)
  * \sa rig_get_vfo()
  */
 
-int rig_set_vfo(RIG *rig, vfo_t vfo)
+int HAMLIB_API rig_set_vfo(RIG *rig, vfo_t vfo)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -995,7 +1071,7 @@ int rig_set_vfo(RIG *rig, vfo_t vfo)
  * \sa rig_set_vfo()
  */
 
-int rig_get_vfo(RIG *rig, vfo_t *vfo)
+int HAMLIB_API rig_get_vfo(RIG *rig, vfo_t *vfo)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1028,7 +1104,7 @@ int rig_get_vfo(RIG *rig, vfo_t *vfo)
  *
  * \sa rig_get_ptt()
  */
-int rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
+int HAMLIB_API rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1062,12 +1138,13 @@ int rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 			break;
 
 		case RIG_PTT_SERIAL_DTR:
+	                        return ser_set_dtr(&rig->state.pttport, ptt==RIG_PTT_ON);
+
 		case RIG_PTT_SERIAL_RTS:
-				ser_ptt_set(&rig->state.pttport, ptt);
-				break;
+	                        return ser_set_rts(&rig->state.pttport, ptt==RIG_PTT_ON);
+
 		case RIG_PTT_PARALLEL:
-				par_ptt_set(&rig->state.pttport, ptt);
-				break;
+				return par_ptt_set(&rig->state.pttport, ptt);
 
 		case RIG_PTT_NONE:
 				return -RIG_ENAVAIL;	/* not available */
@@ -1092,10 +1169,10 @@ int rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
  *
  * \sa rig_set_ptt()
  */
-int rig_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
+int HAMLIB_API rig_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {	
 		const struct rig_caps *caps;
-		int retcode;
+		int retcode, status;
 		vfo_t curr_vfo;
 
 		if (CHECK_RIG_ARG(rig) || !ptt)
@@ -1126,12 +1203,17 @@ int rig_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 			break;
 
 		case RIG_PTT_SERIAL_RTS:
+			retcode = ser_get_rts(&rig->state.pttport, &status);
+			*ptt = status ? RIG_PTT_ON : RIG_PTT_OFF;
+			return retcode;
+
 		case RIG_PTT_SERIAL_DTR:
-				ser_ptt_get(&rig->state.pttport, ptt);
-				break;
+			retcode = ser_get_dtr(&rig->state.pttport, &status);
+			*ptt = status ? RIG_PTT_ON : RIG_PTT_OFF;
+			return retcode;
+
 		case RIG_PTT_PARALLEL:
-				par_ptt_get(&rig->state.pttport, ptt);
-				break;
+				return par_ptt_get(&rig->state.pttport, ptt);
 
 		case RIG_PTT_NONE:
 				return -RIG_ENAVAIL;	/* not available */
@@ -1156,10 +1238,10 @@ int rig_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
  * set appropriately).
  *
  */
-int rig_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
+int HAMLIB_API rig_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {	
 		const struct rig_caps *caps;
-		int retcode;
+		int retcode, status;
 		vfo_t curr_vfo;
 
 		if (CHECK_RIG_ARG(rig) || !dcd)
@@ -1190,12 +1272,23 @@ int rig_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 			break;
 
 		case RIG_DCD_SERIAL_CTS:
+			retcode = ser_get_cts(&rig->state.dcdport, &status);
+			*dcd = status ? RIG_DCD_ON : RIG_DCD_OFF;
+			return retcode;
+
 		case RIG_DCD_SERIAL_DSR:
-				ser_dcd_get(&rig->state.dcdport, dcd);
-				break;
+			retcode = ser_get_dsr(&rig->state.dcdport, &status);
+			*dcd = status ? RIG_DCD_ON : RIG_DCD_OFF;
+			return retcode;
+
+		case RIG_DCD_SERIAL_CAR:
+			retcode = ser_get_car(&rig->state.dcdport, &status);
+			*dcd = status ? RIG_DCD_ON : RIG_DCD_OFF;
+			return retcode;
+
+			
 		case RIG_DCD_PARALLEL:
-				par_dcd_get(&rig->state.dcdport, dcd);
-				break;
+			return par_dcd_get(&rig->state.dcdport, dcd);
 
 		case RIG_DCD_NONE:
 				return -RIG_ENAVAIL;	/* not available */
@@ -1222,7 +1315,7 @@ int rig_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
  *
  * \sa rig_get_rptr_shift()
  */
-int rig_set_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t rptr_shift)
+int HAMLIB_API rig_set_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t rptr_shift)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1266,7 +1359,7 @@ int rig_set_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t rptr_shift)
  *
  * \sa rig_set_rptr_shift()
  */
-int rig_get_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t *rptr_shift)
+int HAMLIB_API rig_get_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t *rptr_shift)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1311,7 +1404,7 @@ int rig_get_rptr_shift(RIG *rig, vfo_t vfo, rptr_shift_t *rptr_shift)
  * \sa rig_get_rptr_offs()
  */
 
-int rig_set_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t rptr_offs)
+int HAMLIB_API rig_set_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t rptr_offs)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1356,7 +1449,7 @@ int rig_set_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t rptr_offs)
  * \sa rig_set_rptr_offs()
  */
 
-int rig_get_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t *rptr_offs)
+int HAMLIB_API rig_get_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t *rptr_offs)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1402,7 +1495,7 @@ int rig_get_rptr_offs(RIG *rig, vfo_t vfo, shortfreq_t *rptr_offs)
  * \sa rig_get_split_freq()
  */
 
-int rig_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
+int HAMLIB_API rig_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1446,7 +1539,7 @@ int rig_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
  *
  * \sa rig_set_split_freq()
  */
-int rig_get_split_freq(RIG *rig, vfo_t vfo, freq_t *tx_freq)
+int HAMLIB_API rig_get_split_freq(RIG *rig, vfo_t vfo, freq_t *tx_freq)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1492,7 +1585,7 @@ int rig_get_split_freq(RIG *rig, vfo_t vfo, freq_t *tx_freq)
  * \sa rig_get_split_mode()
  */
 
-int rig_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
+int HAMLIB_API rig_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1537,7 +1630,7 @@ int rig_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
  *
  * \sa rig_set_split_mode()
  */
-int rig_get_split_mode(RIG *rig, vfo_t vfo, rmode_t *tx_mode, pbwidth_t *tx_width)
+int HAMLIB_API rig_get_split_mode(RIG *rig, vfo_t vfo, rmode_t *tx_mode, pbwidth_t *tx_width)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1583,7 +1676,7 @@ int rig_get_split_mode(RIG *rig, vfo_t vfo, rmode_t *tx_mode, pbwidth_t *tx_widt
  *
  * \sa rig_get_split_vfo()
  */
-int rig_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
+int HAMLIB_API rig_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1628,7 +1721,7 @@ int rig_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
  *
  * \sa rig_set_split_vfo()
  */
-int rig_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
+int HAMLIB_API rig_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1673,7 +1766,7 @@ int rig_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
  * \sa rig_get_rit()
  */
 
-int rig_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
+int HAMLIB_API rig_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1718,7 +1811,7 @@ int rig_set_rit(RIG *rig, vfo_t vfo, shortfreq_t rit)
  * \sa rig_set_rit()
  */
 
-int rig_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
+int HAMLIB_API rig_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1763,7 +1856,7 @@ int rig_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
  * \sa rig_get_xit()
  */
 
-int rig_set_xit(RIG *rig, vfo_t vfo, shortfreq_t xit)
+int HAMLIB_API rig_set_xit(RIG *rig, vfo_t vfo, shortfreq_t xit)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1808,7 +1901,7 @@ int rig_set_xit(RIG *rig, vfo_t vfo, shortfreq_t xit)
  * \sa rig_set_xit()
  */
 
-int rig_get_xit(RIG *rig, vfo_t vfo, shortfreq_t *xit)
+int HAMLIB_API rig_get_xit(RIG *rig, vfo_t vfo, shortfreq_t *xit)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1855,7 +1948,7 @@ int rig_get_xit(RIG *rig, vfo_t vfo, shortfreq_t *xit)
  * \sa rig_get_ts()
  */
 
-int rig_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
+int HAMLIB_API rig_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1900,7 +1993,7 @@ int rig_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
  * \sa rig_set_ts()
  */
 
-int rig_get_ts(RIG *rig, vfo_t vfo, shortfreq_t *ts)
+int HAMLIB_API rig_get_ts(RIG *rig, vfo_t vfo, shortfreq_t *ts)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1949,7 +2042,7 @@ int rig_get_ts(RIG *rig, vfo_t vfo, shortfreq_t *ts)
  * \sa rig_get_ant()
  */
 
-int rig_set_ant(RIG *rig, vfo_t vfo, ant_t ant)
+int HAMLIB_API rig_set_ant(RIG *rig, vfo_t vfo, ant_t ant)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -1994,7 +2087,7 @@ int rig_set_ant(RIG *rig, vfo_t vfo, ant_t ant)
  * \sa rig_set_ant()
  */
 
-int rig_get_ant(RIG *rig, vfo_t vfo, ant_t *ant)
+int HAMLIB_API rig_get_ant(RIG *rig, vfo_t vfo, ant_t *ant)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -2046,7 +2139,7 @@ int rig_get_ant(RIG *rig, vfo_t vfo, ant_t *ant)
  *
  * \sa rig_mW2power()
  */
-int rig_power2mW(RIG *rig, unsigned int *mwpower, float power, freq_t freq, rmode_t mode)
+int HAMLIB_API rig_power2mW(RIG *rig, unsigned int *mwpower, float power, freq_t freq, rmode_t mode)
 {
 		const freq_range_t *txrange;
 
@@ -2087,7 +2180,7 @@ int rig_power2mW(RIG *rig, unsigned int *mwpower, float power, freq_t freq, rmod
  *
  * \sa rig_power2mW()
  */
-int rig_mW2power(RIG *rig, float *power, unsigned int mwpower, freq_t freq, rmode_t mode)
+int HAMLIB_API rig_mW2power(RIG *rig, float *power, unsigned int mwpower, freq_t freq, rmode_t mode)
 {
 		const freq_range_t *txrange;
 
@@ -2125,7 +2218,7 @@ int rig_mW2power(RIG *rig, float *power, unsigned int mwpower, freq_t freq, rmod
  * has been sucessful, otherwise a negative value if an error occured.
  *
  */
-shortfreq_t rig_get_resolution(RIG *rig, rmode_t mode)
+shortfreq_t HAMLIB_API rig_get_resolution(RIG *rig, rmode_t mode)
 {
 		const struct rig_state *rs;
 		int i;
@@ -2160,7 +2253,7 @@ shortfreq_t rig_get_resolution(RIG *rig, rmode_t mode)
  * \sa rig_get_powerstat()
  */
 
-int rig_set_powerstat(RIG *rig, powerstat_t status)
+int HAMLIB_API rig_set_powerstat(RIG *rig, powerstat_t status)
 {
 		if (CHECK_RIG_ARG(rig))
 			return -RIG_EINVAL;
@@ -2186,7 +2279,7 @@ int rig_set_powerstat(RIG *rig, powerstat_t status)
  * \sa rig_set_powerstat()
  */
 
-int rig_get_powerstat(RIG *rig, powerstat_t *status)
+int HAMLIB_API rig_get_powerstat(RIG *rig, powerstat_t *status)
 {
 		if (CHECK_RIG_ARG(rig) || !status)
 			return -RIG_EINVAL;
@@ -2212,7 +2305,7 @@ int rig_get_powerstat(RIG *rig, powerstat_t *status)
  *
  */
 
-int rig_reset(RIG *rig, reset_t reset)
+int HAMLIB_API rig_reset(RIG *rig, reset_t reset)
 {
 		if (CHECK_RIG_ARG(rig))
 			return -RIG_EINVAL;
@@ -2239,7 +2332,7 @@ extern int rig_probe_all_backends(port_t *p, rig_probe_func_t cfunc, rig_ptr_t d
  * \return the rig model id according to the rig_model_t type if found, 
  * otherwise RIG_MODEL_NONE if unable to determine rig model.
  */
-rig_model_t rig_probe(port_t *port)
+rig_model_t HAMLIB_API rig_probe(port_t *port)
 {
 	if (!port)
 		return RIG_MODEL_NONE;
@@ -2264,7 +2357,7 @@ rig_model_t rig_probe(port_t *port)
  * a negative value if an error occured (in which case, cause is 
  * set appropriately).
  */
-int rig_probe_all(port_t *port, rig_probe_func_t cfunc, rig_ptr_t data)
+int HAMLIB_API rig_probe_all(port_t *port, rig_probe_func_t cfunc, rig_ptr_t data)
 {
 	if (!port)
 		return -RIG_EINVAL;
@@ -2288,7 +2381,7 @@ int rig_probe_all(port_t *port, rig_probe_func_t cfunc, rig_ptr_t data)
  *
  * \sa rig_vfo_op()
  */
-vfo_op_t rig_has_vfo_op(RIG *rig, vfo_op_t op)
+vfo_op_t HAMLIB_API rig_has_vfo_op(RIG *rig, vfo_op_t op)
 {
 		if (!rig || !rig->caps)
 				return 0;
@@ -2312,7 +2405,7 @@ vfo_op_t rig_has_vfo_op(RIG *rig, vfo_op_t op)
  * \sa rig_has_vfo_op()
  */
 
-int rig_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
+int HAMLIB_API rig_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -2358,7 +2451,7 @@ int rig_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
  *
  * \sa rig_scan()
  */
-scan_t rig_has_scan(RIG *rig, scan_t scan)
+scan_t HAMLIB_API rig_has_scan(RIG *rig, scan_t scan)
 {
 		if (!rig || !rig->caps)
 				return 0;
@@ -2383,7 +2476,7 @@ scan_t rig_has_scan(RIG *rig, scan_t scan)
  * \sa rig_has_scan()
  */
 
-int rig_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch)
+int HAMLIB_API rig_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -2429,7 +2522,7 @@ int rig_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch)
  *
  */
 
-int rig_send_dtmf(RIG *rig, vfo_t vfo, const char *digits)
+int HAMLIB_API rig_send_dtmf(RIG *rig, vfo_t vfo, const char *digits)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -2475,7 +2568,7 @@ int rig_send_dtmf(RIG *rig, vfo_t vfo, const char *digits)
  *
  */
 
-int rig_recv_dtmf(RIG *rig, vfo_t vfo, char *digits, int *length)
+int HAMLIB_API rig_recv_dtmf(RIG *rig, vfo_t vfo, char *digits, int *length)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -2520,7 +2613,7 @@ int rig_recv_dtmf(RIG *rig, vfo_t vfo, char *digits, int *length)
  *
  */
 
-int rig_send_morse(RIG *rig, vfo_t vfo, const char *msg)
+int HAMLIB_API rig_send_morse(RIG *rig, vfo_t vfo, const char *msg)
 {
 		const struct rig_caps *caps;
 		int retcode;
@@ -2565,7 +2658,7 @@ int rig_send_morse(RIG *rig, vfo_t vfo, const char *msg)
  *
  */
 const freq_range_t *
-rig_get_range(const freq_range_t range_list[], freq_t freq, rmode_t mode)
+HAMLIB_API rig_get_range(const freq_range_t range_list[], freq_t freq, rmode_t mode)
 {
 	int i;
 
@@ -2581,211 +2674,6 @@ rig_get_range(const freq_range_t range_list[], freq_t freq, rmode_t mode)
 	return NULL;
 }
 
-/**
- * \brief set the callback for freq events
- * \param rig	The rig handle
- * \param cb	The callback to install
- * \param arg	A Pointer to some private data to pass later on to the callback
- *
- *  Install a callback for freq events, to be called when in transceive mode.
- *
- * \return RIG_OK if the operation has been sucessful, otherwise 
- * a negative value if an error occured (in which case, cause is 
- * set appropriately).
- *
- * \sa rig_set_trn()
- */
-
-int rig_set_freq_callback(RIG *rig, freq_cb_t cb, rig_ptr_t arg)
-{
-		if (CHECK_RIG_ARG(rig))
-			return -RIG_EINVAL;
-
-		rig->callbacks.freq_event = cb;
-		rig->callbacks.freq_arg = arg;
-
-		return RIG_OK;
-}
-
-/**
- * \brief set the callback for mode events
- * \param rig	The rig handle
- * \param cb	The callback to install
- * \param arg	A Pointer to some private data to pass later on to the callback
- *
- *  Install a callback for mode events, to be called when in transceive mode.
- *
- * \return RIG_OK if the operation has been sucessful, otherwise 
- * a negative value if an error occured (in which case, cause is 
- * set appropriately).
- *
- * \sa rig_set_trn()
- */
-
-int rig_set_mode_callback(RIG *rig, mode_cb_t cb, rig_ptr_t arg)
-{
-		if (CHECK_RIG_ARG(rig))
-			return -RIG_EINVAL;
-
-		rig->callbacks.mode_event = cb;
-		rig->callbacks.mode_arg = arg;
-
-		return RIG_OK;
-}
-
-/**
- * \brief set the callback for vfo events
- * \param rig	The rig handle
- * \param cb	The callback to install
- * \param arg	A Pointer to some private data to pass later on to the callback
- *
- *  Install a callback for vfo events, to be called when in transceive mode.
- *
- * \return RIG_OK if the operation has been sucessful, otherwise 
- * a negative value if an error occured (in which case, cause is 
- * set appropriately).
- *
- * \sa rig_set_trn()
- */
-
-int rig_set_vfo_callback(RIG *rig, vfo_cb_t cb, rig_ptr_t arg)
-{
-		if (CHECK_RIG_ARG(rig))
-			return -RIG_EINVAL;
-
-		rig->callbacks.vfo_event = cb;
-		rig->callbacks.vfo_arg = arg;
-
-		return RIG_OK;
-}
-
-/**
- * \brief set the callback for ptt events
- * \param rig	The rig handle
- * \param cb	The callback to install
- * \param arg	A Pointer to some private data to pass later on to the callback
- *
- *  Install a callback for ptt events, to be called when in transceive mode.
- *
- * \return RIG_OK if the operation has been sucessful, otherwise 
- * a negative value if an error occured (in which case, cause is 
- * set appropriately).
- *
- * \sa rig_set_trn()
- */
-
-int rig_set_ptt_callback(RIG *rig, ptt_cb_t cb, rig_ptr_t arg)
-{
-		if (CHECK_RIG_ARG(rig))
-			return -RIG_EINVAL;
-
-		rig->callbacks.ptt_event = cb;
-		rig->callbacks.ptt_arg = arg;
-
-		return RIG_OK;
-}
-
-/**
- * \brief set the callback for dcd events
- * \param rig	The rig handle
- * \param cb	The callback to install
- * \param arg	A Pointer to some private data to pass later on to the callback
- *
- *  Install a callback for dcd events, to be called when in transceive mode.
- *
- * \return RIG_OK if the operation has been sucessful, otherwise 
- * a negative value if an error occured (in which case, cause is 
- * set appropriately).
- *
- * \sa rig_set_trn()
- */
-
-int rig_set_dcd_callback(RIG *rig, dcd_cb_t cb, rig_ptr_t arg)
-{
-		if (CHECK_RIG_ARG(rig))
-			return -RIG_EINVAL;
-
-		rig->callbacks.dcd_event = cb;
-		rig->callbacks.dcd_arg = arg;
-
-		return RIG_OK;
-}
-
-/**
- * \brief control the transceive mode 
- * \param rig	The rig handle
- * \param trn	The transceive status to set to
- *
- *  Enable/disable the transceive handling of a rig and kick off async mode.
- *
- * \return RIG_OK if the operation has been sucessful, otherwise 
- * a negative value if an error occured (in which case, cause is 
- * set appropriately).
- *
- * \sa rig_get_trn()
- */
-
-int rig_set_trn(RIG *rig, int trn)
-{
-		const struct rig_caps *caps;
-		int status;
-
-		if (CHECK_RIG_ARG(rig))
-			return -RIG_EINVAL;
-
-		caps = rig->caps;
-
-		if (rig->state.transceive == RIG_TRN_OFF)
-			return -RIG_ENAVAIL;
-
-		if (trn == RIG_TRN_RIG) {
-			if (rig->state.transceive) {
-				/*
-				 * TODO: check error codes et al.
-				 */
-				status = add_trn_rig(rig);
-				if (status == RIG_OK && caps->set_trn)
-						return caps->set_trn(rig, RIG_TRN_RIG);
-				else
-						return status;
-			} else {
-				return -RIG_ECONF;
-			}
-		} else {
-				status = remove_trn_rig(rig);
-				if (caps->set_trn)
-						return caps->set_trn(rig, RIG_TRN_OFF);
-				else
-						return status;
-		}
-
-		return RIG_OK;
-}
-
-/**
- * \brief get the current transceive mode
- * \param rig	The rig handle
- * \param trn	The location where to store the current transceive mode
- *
- *  Retrieves the current status of the transceive mode, i.e. if radio 
- *  sends new status automatically when some changes happened on the radio.
- *
- * \return RIG_OK if the operation has been sucessful, otherwise 
- * a negative value if an error occured (in which case, cause is 
- * set appropriately).
- *
- * \sa rig_set_trn()
- */
-int rig_get_trn(RIG *rig, int *trn)
-{
-		if (CHECK_RIG_ARG(rig) || !trn)
-			return -RIG_EINVAL;
-
-		if (rig->caps->get_trn == NULL)
-			return -RIG_ENAVAIL;
-
-		return rig->caps->get_trn(rig, trn);
-}
 
 /**
  * \brief get general information from the radio
@@ -2798,7 +2686,7 @@ int rig_get_trn(RIG *rig, int *trn)
  * if the operation has been sucessful, otherwise NULL if an error occured
  * or get_info not part of capabilities.
  */
-const char* rig_get_info(RIG *rig)
+const char* HAMLIB_API rig_get_info(RIG *rig)
 {
 		if (CHECK_RIG_ARG(rig))
 			return NULL;
