@@ -1,9 +1,9 @@
 /*
- * dumpcaps.c - Copyright (C) 2000-2003 Stephane Fillod
+ * dumpcaps.c - Copyright (C) 2000-2004 Stephane Fillod
  * This programs dumps the capabilities of a backend rig.
  *
  *
- *    $Id: dumpcaps.c,v 1.41 2003/12/04 23:18:49 fillods Exp $  
+ *    $Id: dumpcaps.c,v 1.43 2004/09/26 08:35:04 fillods Exp $  
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -63,7 +63,7 @@ int dumpcaps (RIG* rig)
 	printf("Mfg name:\t%s\n",caps->mfg_name);
 	printf("Backend version:\t%s\n",caps->version);
 	printf("Backend copyright:\t%s\n",caps->copyright);
-	printf("Backend status:\t%s\n", strstatus(caps->status));
+	printf("Backend status:\t%s\n", rig_strstatus(caps->status));
 	printf("Rig type:\t");
 	switch (caps->rig_type & RIG_TYPE_MASK) {
 	case RIG_TYPE_TRANSCEIVER:
@@ -225,6 +225,17 @@ int dumpcaps (RIG* rig)
 	sprintf_level_gran(prntbuf, caps->has_get_level, caps->level_gran);
 	printf("Get level: %s\n", prntbuf);
 
+	if ((caps->has_get_level&RIG_LEVEL_SQLSTAT)) {
+			printf("Warning: backend uses deprecated SQLSTAT level!\n");
+			backend_warnings++;
+	}
+
+	if ((caps->has_get_level&RIG_LEVEL_RAWSTR) &&
+				caps->str_cal.size == 0) {
+			printf("Warning: backend has get RAWSTR, but not calibration data\n");
+			backend_warnings++;
+	}
+
 	sprintf_level_gran(prntbuf, caps->has_set_level, caps->level_gran);
 	printf("Set level: %s\n", prntbuf);
 	if (caps->has_set_level&RIG_LEVEL_READONLY_LIST) {
@@ -332,7 +343,7 @@ int dumpcaps (RIG* rig)
 			continue;
 
 		sprintf_freq(freqbuf, pbnorm);
-		printf("\n\t%s\tnormal: %s,\t", strrmode(i), freqbuf);
+		printf("\n\t%s\tnormal: %s,\t", rig_strrmode(i), freqbuf);
 
 		sprintf_freq(freqbuf, rig_passband_narrow(rig, i));
 		printf("narrow: %s,\t", freqbuf);
