@@ -6,7 +6,7 @@
  * via serial interface to an FT-847 using the "CAT" interface.
  *
  *
- * $Id: ft847.c,v 1.27 2004/02/16 21:38:59 fillods Exp $  
+ * $Id: ft847.c,v 1.29 2004/11/17 22:02:03 fillods Exp $  
  *
  *
  *
@@ -184,7 +184,7 @@ const struct rig_caps ft847_caps = {
 .rig_model =  RIG_MODEL_FT847,
 .model_name = "FT-847", 
 .mfg_name =  "Yaesu", 
-.version =  "0.1", 
+.version =  "0.1.1", 
 .copyright =  "LGPL",
 .status =  RIG_STATUS_ALPHA,
 .rig_type =  RIG_TYPE_TRANSCEIVER,
@@ -461,7 +461,7 @@ int ft847_set_freq(RIG *rig, vfo_t vfo, freq_t freq) {
    */
 
 
-  rig_debug(RIG_DEBUG_VERBOSE,"ft847: vfo =%s \n", strvfo(vfo));
+  rig_debug(RIG_DEBUG_VERBOSE,"ft847: vfo =%s \n", rig_strvfo(vfo));
   
   if (vfo == RIG_VFO_CURR)
 	vfo = p->current_vfo;
@@ -510,7 +510,7 @@ static int get_freq_and_mode(RIG *rig, vfo_t vfo, freq_t *freq, rmode_t *mode,
 
   p = (struct ft847_priv_data*)rs->priv;
 
-  rig_debug(RIG_DEBUG_VERBOSE,"ft847: vfo =%s \n", strvfo(vfo));
+  rig_debug(RIG_DEBUG_VERBOSE,"ft847: vfo =%s \n", rig_strvfo(vfo));
   
   if (vfo == RIG_VFO_CURR)
 	vfo = p->current_vfo;
@@ -623,7 +623,7 @@ int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width) {
 	vfo = p->current_vfo;
 
   if (vfo != RIG_VFO_MAIN) {
-    rig_debug(RIG_DEBUG_VERBOSE,"ft847: unsupported VFO '%s'\n", strvfo(vfo));
+    rig_debug(RIG_DEBUG_VERBOSE,"ft847: unsupported VFO '%s'\n", rig_strvfo(vfo));
     return -RIG_ENIMPL;		/* sorry, it's in TODO list */
   }
 
@@ -664,7 +664,13 @@ int ft847_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width) {
     case RIG_MODE_CW:
       cmd_index = FT_847_NATIVE_CAT_SET_MODE_MAIN_CWN;
       break;
+    case RIG_MODE_USB:
+    case RIG_MODE_LSB:
+      break;
     default:
+      rig_debug(RIG_DEBUG_ERR,"%s: unsupported mode/width: %s/%d, narrow: %d\n",
+		      __FUNCTION__, rig_strrmode(mode), width, 
+		      rig_passband_narrow(rig, mode));
       return -RIG_EINVAL;		/* sorry, wrong MODE/WIDTH combo  */    
     }
   } else {
