@@ -1,13 +1,13 @@
 /*
  * hamlib - (C) Frank Singleton 2000 (vk3fcs@ix.netcom.com)
  *
- * yaesu.c - (C) Stephane Fillod 2001-2003
+ * yaesu.c - (C) Stephane Fillod 2001-2004
  *
  * This shared library provides an API for communicating
  * via serial interface to a Yaesu rig
  *
  *
- *	$Id: yaesu.c,v 1.17 2004/02/08 17:08:46 fillods Exp $  
+ *	$Id: yaesu.c,v 1.22 2004/08/17 20:07:20 fillods Exp $  
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -51,7 +51,10 @@ DECLARE_INITRIG_BACKEND(yaesu)
   rig_debug(RIG_DEBUG_VERBOSE, "yaesu: %s called\n", __func__);
 
   rig_register(&ft100_caps);
+  rig_register(&ft736_caps);
   rig_register(&ft747_caps);
+  rig_register(&ft757gx_caps);
+  rig_register(&ft757gx2_caps);
   rig_register(&ft817_caps);
   rig_register(&ft847_caps);
   rig_register(&ft857_caps);
@@ -60,7 +63,11 @@ DECLARE_INITRIG_BACKEND(yaesu)
   rig_register(&ft900_caps);
   rig_register(&ft920_caps);
   rig_register(&ft990_caps);
+  rig_register(&ft1000d_caps);
   rig_register(&ft1000mp_caps);
+  rig_register(&frg100_caps);
+  rig_register(&frg8800_caps);
+  rig_register(&frg9600_caps);
 
   return RIG_OK;
 }
