@@ -2,11 +2,11 @@
  * hamlib - (C) Frank Singleton 2000 (vk3fcs@ix.netcom.com)
  *
  * yaesu.h - (C) Frank Singleton 2000 (vk3fcs@ix.netcom.com)
- *		and Stephane Fillod 2001-2003
+ *		and Stephane Fillod 2001-2004
  *
  * Common yaesu declarations for hamlib
  *
- * 	$Id: yaesu.h,v 1.19 2004/02/08 17:08:46 fillods Exp $	
+ * 	$Id: yaesu.h,v 1.24 2004/08/17 20:07:20 fillods Exp $	
  *
  *
  *
@@ -48,7 +48,10 @@ struct yaesu_cmd_set {
 typedef struct yaesu_cmd_set yaesu_cmd_set_t; 
 
 extern const struct rig_caps ft100_caps;
+extern const struct rig_caps ft736_caps;
 extern const struct rig_caps ft747_caps;
+extern const struct rig_caps ft757gx_caps;
+extern const struct rig_caps ft757gx2_caps;
 extern const struct rig_caps ft817_caps;
 extern const struct rig_caps ft857_caps;
 extern const struct rig_caps ft897_caps;
@@ -58,5 +61,9 @@ extern const struct rig_caps ft900_caps;
 extern const struct rig_caps ft920_caps;
 extern const struct rig_caps ft990_caps;
 extern const struct rig_caps ft1000mp_caps;
+extern const struct rig_caps ft1000d_caps;
+extern const struct rig_caps frg100_caps;
+extern const struct rig_caps frg8800_caps;
+extern const struct rig_caps frg9600_caps;
 
 #endif /* _YAESU_H */
